@@ -622,8 +622,8 @@ public abstract class BaseHiveEvent {
 
         if (context.isHiveProcessPopulateDeprecatedAttributes()) {
             ret.setAttribute(ATTRIBUTE_USER_NAME, getUserName());
-            ret.setAttribute(ATTRIBUTE_QUERY_TEXT, queryStr);
-            ret.setAttribute(ATTRIBUTE_QUERY_ID, getQueryId());
+            ret.setAttribute(ATTRIBUTE_QUERY_TEXT, StringUtils.isNotEmpty(queryStr)? queryStr : EMPTY_ATTRIBUTE_VALUE);
+            ret.setAttribute(ATTRIBUTE_QUERY_ID, StringUtils.isNotEmpty(getQueryId())? getQueryId() : EMPTY_ATTRIBUTE_VALUE);
         } else {
             ret.setAttribute(ATTRIBUTE_USER_NAME, EMPTY_ATTRIBUTE_VALUE);
             ret.setAttribute(ATTRIBUTE_QUERY_TEXT, EMPTY_ATTRIBUTE_VALUE);
@@ -767,7 +767,13 @@ public abstract class BaseHiveEvent {
     }
 
     protected Long getQueryStartTime() {
-        return isHiveContextValid() ? context.getHiveContext().getQueryPlan().getQueryStartTime() : System.currentTimeMillis();
+        Long queryStartTime = null;
+
+        if (isHiveContextValid() && context.getHiveContext().getQueryPlan() != null) {
+            queryStartTime = context.getHiveContext().getQueryPlan().getQueryStartTime();
+        }
+
+        return queryStartTime == null ? System.currentTimeMillis() : queryStartTime;
     }
 
     protected String getQueryId() {
