@@ -17,10 +17,11 @@
  */
 define(['require',
     'utils/Utils',
+    'utils/Globals',
     'd3',
     'marionette',
     'jquery-ui'
-], function(require, Utils, d3) {
+], function(require, Utils, Globals, d3) {
     'use strict';
     _.mixin({
         numberFormatWithComma: function(number) {
@@ -127,6 +128,12 @@ define(['require',
     $("body").on('click', '.btn', function() {
         $(this).blur();
     });
+    $('body').on('click', function(e) {
+        if ($(e.target).hasClass('trumbowyg-editor-hidden')) {
+            $('.trumbowyg').find('.trumbowyg-button-pane').removeClass('trumbowyg-button-pane-hidden');
+            $('.trumbowyg').css('border', '1px solid #8fa5b1');
+        }
+    });
     $('body').on('keyup input', '.modal-body', function(e) {
         var target = e.target,
             isGlossary = (e.target.dataset.id === "searchTerm" || e.target.dataset.id === "searchCategory") ? true : false; // assign term/category modal
@@ -372,7 +379,13 @@ define(['require',
         });
     }
     //For closing the modal on browsers navigation
-    $(window).on('popstate', function(){
+    $(window).on('popstate', function() {
         $('body').find('.modal-dialog .close').click();
+        //To close the full-screen mode in lineage on browsers navigation.
+        if (!Globals.isFullScreenView) {
+            $('#tab-lineage').removeClass("fullscreen-mode");
+            $("#r_lineageLayoutView").find('button[data-id="fullScreen-toggler"]').attr("data-original-title", "Full Screen").find("i").removeClass("fa-compress").addClass("fa-expand");
+        }
+        Globals.isFullScreenView = false;
     });
 })
\ No newline at end of file
