@@ -43,9 +43,21 @@ define(['require', 'utils/Enums', 'utils/Utils', 'underscore'], function(require
         enumDefApiUrl: function(name) {
             return this.getDefApiUrl('enum', name);
         },
+        relationshipDefApiUrl: function() {
+            return this.getDefApiUrl('relationship', name);
+        },
         metricsApiUrl: function() {
             return this.baseUrl + '/admin/metrics'
         },
+        metricsAllCollectionTimeApiUrl: function() {
+            return this.baseUrl + '/admin/metricsstats'
+        },
+        metricsCollectionTimeApiUrl: function() {
+            return this.baseUrl + '/admin/metricsstat/'
+        },
+        metricsGraphUrl:function(){
+            return this.baseUrl + '/admin/metricsstats/charts'
+        },
         pendingTaskApiUrl: function() {
             return this.baseUrl + '/admin/tasks'
         },
@@ -97,6 +109,16 @@ define(['require', 'utils/Enums', 'utils/Utils', 'underscore'], function(require
                 return entitiesUrl += '?minExtInfo=' + (minExtInfo);
             }
         },
+        relationApiUrl: function(options) {
+            var relationsUrl = this.baseUrlV2 + '/relationship';
+            if (options) {
+                var guid = options.guid,
+                    name = options.name;
+                if (guid)
+                    relationsUrl += '/guid/' + guid;
+            }
+            return relationsUrl;
+        },
         entityLabelsAPIUrl: function(guid) {
             return this.entitiesApiUrl({ guid: guid }) + "/labels";
         },
@@ -169,6 +191,9 @@ define(['require', 'utils/Enums', 'utils/Utils', 'underscore'], function(require
                 return relationshipUrl
             }
         },
+        relationshipSearchApiUrl: function() {
+            return this.baseUrlV2 + '/search/relations';
+        },
         schemaApiUrl: function(guid) {
             var lineageUrl = this.baseUrl + '/lineage';
             if (guid) {
