@@ -215,6 +215,7 @@ define(['require',
                         isNewBusinessMetadata: isNewBusinessMetadata
                     });
                     that.RModal.show(that.view);
+                    Utils.addCustomTextEditor({ small: false });
                 });
             },
             renderTableLayoutView: function() {
@@ -296,7 +297,11 @@ define(['require',
                         editable: false,
                         formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
                             fromRaw: function(rawValue, model) {
-                                return _.escape(model.get('description'));
+                                var description = model.get('description');
+                                if (description.length > 50) {
+                                    description = description.substr(0, 50) + "...";
+                                }
+                                return description;
                             }
                         })
                     },
