@@ -57,8 +57,7 @@ define(['require',
                 toggleRequired: 'input[name="toggleRequired"]',
                 assetName: "[data-id='assetName']",
                 entityInput: "[data-id='entityInput']",
-                entitySelectionBox: "[data-id='entitySelectionBox']",
-
+                entitySelectionBox: "[data-id='entitySelectionBox']"
             },
             /** ui events hash */
             events: function() {
@@ -150,7 +149,7 @@ define(['require',
                 });
 
                 this.ui.entityInputData.on('keyup change', 'input.true,select.true', function(e) {
-                    if (this.value !== "") {
+                    if (this.value.trim() !== "") {
                         if ($(this).data('select2')) {
                             $(this).data('select2').$container.find('.select2-selection').removeClass("errorClass");
                         } else {
@@ -293,6 +292,7 @@ define(['require',
                         that.subAttributeData(data)
                     },
                     complete: function() {
+                        that.modal.$el.find('button.ok').prop("disabled", true);
                         //that.initilizeElements();
                     },
                     silent: true
@@ -433,22 +433,31 @@ define(['require',
                 that.initilizeElements();
             },
             initilizeElements: function() {
-                var that = this;
+                var that = this,
+                    $createTime = this.modal.$el.find('input[name="createTime"]'),
+                    dateObj = {
+                        "singleDatePicker": true,
+                        "showDropdowns": true,
+                        "startDate": new Date(),
+                        locale: {
+                            format: Globals.dateFormat
+                        }
+                    };
                 this.$('input[data-type="date"]').each(function() {
                     if (!$(this).data('daterangepicker')) {
-                        var dateObj = {
-                            "singleDatePicker": true,
-                            "showDropdowns": true,
-                            locale: {
-                                format: Globals.dateFormat
-                            }
-                        };
-                        if (that.guid) {
+                        if (that.guid && this.value.length) {
                             dateObj["startDate"] = new Date(Number(this.value));
                         }
+                        if ($(this).attr('name') === "modifiedTime") {
+                            dateObj["minDate"] = $createTime.val();
+                        }
                         $(this).daterangepicker(dateObj);
                     }
                 });
+                modifiedDateObj = _.extend({}, dateObj);
+                $createTime.on('apply.daterangepicker', function(ev, picker) {
+                    that.modal.$el.find('input[name="modifiedTime"]').daterangepicker(_.extend(modifiedDateObj, { "minDate": $createTime.val() }));
+                });
                 this.initializeValidation();
                 if (this.ui.entityInputData.find('fieldset').length > 0 && this.ui.entityInputData.find('select.true,input.true').length === 0) {
                     this.requiredAllToggle(this.ui.entityInputData.find('select.true,input.true').length === 0);
@@ -586,6 +595,7 @@ define(['require',
                     ' data-attribute="' + isAttribute + '"' +
                     ' data-relation="' + isRelation + '"' +
                     ' placeholder="' + name + '"' +
+                    ' name="' + name + '"' +
                     ' data-id="entityInput">';
             },
             getElement: function(object) {
@@ -606,7 +616,7 @@ define(['require',
                             if (dataValue) {
                                 entityValue = moment(dataValue);
                             } else {
-                                entityValue = moment().format(Globals.dateFormat);
+                                entityValue = Utils.formatDate({ zone: false, dateFormat: Globals.dateFormat });
                             }
                         }
                     }
@@ -847,7 +857,7 @@ define(['require',
                     if (that.guid) {
                         var dataValue = that.entityData.get("entity").attributes[keyData],
                             entities = that.entityData.get("entity").attributes,
-                            relationshipType = that.entityData.get("entity").relationshipAttributes[keyData],
+                            relationshipType = that.entityData.get("entity").relationshipAttributes ? that.entityData.get("entity").relationshipAttributes[keyData] : null,
                             referredEntities = that.entityData.get("referredEntities"),
                             selectedValue = [],
                             select2Options = [];
