@@ -38,7 +38,8 @@ define(['require',
             /** Layout sub regions */
             regions: {
                 RSaveSearchBasic: "[data-id='r_saveSearchBasic']",
-                RSaveSearchAdvance: "[data-id='r_saveSearchAdvance']"
+                RSaveSearchAdvance: "[data-id='r_saveSearchAdvance']",
+                RRelationSearch: "[data-id='r_relationshipSearch']"
             },
 
             /** ui selector cache */
@@ -53,7 +54,8 @@ define(['require',
                 refreshBtn: '[data-id="refreshBtn"]',
                 advancedInfoBtn: '[data-id="advancedInfo"]',
                 typeAttrFilter: '[data-id="typeAttrFilter"]',
-                tagAttrFilter: '[data-id="tagAttrFilter"]'
+                tagAttrFilter: '[data-id="tagAttrFilter"]',
+                tablist: '[data-id="tab-searchlist"] li'
             },
 
             /** ui events hash */
@@ -77,6 +79,20 @@ define(['require',
                 events["change " + this.ui.termLov] = 'checkForButtonVisiblity';
                 events["click " + this.ui.refreshBtn] = 'onRefreshButton';
                 events["click " + this.ui.advancedInfoBtn] = 'advancedInfo';
+                events["click " + this.ui.tablist] = function(e) {
+                    var tabValue = $(e.currentTarget).attr('role'),
+                        redirectionUrl = '#!/search';
+                    this.isRelationSearch = (tabValue === "relationship-search") ? true : false;
+                    if (this.isRelationSearch) {
+                        redirectionUrl = '#!/relationship';
+                    }
+                    Utils.setUrl({
+                        url: redirectionUrl,
+                        mergeBrowserUrl: false,
+                        trigger: true,
+                        updateTabState: true
+                    });
+                };
                 events["click " + this.ui.typeAttrFilter] = function() {
                     this.openAttrFilter('type');
                 };
@@ -96,7 +112,8 @@ define(['require',
                 this.selectedFilter = {
                     'basic': [],
                     'dsl': []
-                }
+                };
+                this.filterTypeSelected = null;
                 var param = Utils.getUrlState.getQueryParams();
                 this.query = {
                     dsl: {
@@ -136,6 +153,8 @@ define(['require',
                 this.tagEntityCheck = false;
                 this.typeEntityCheck = false;
                 this.bindEvents();
+                this.isRelationSearch = false;
+                this.renderRelationshipSearchView();
             },
             renderSaveSearch: function() {
                 var that = this;
@@ -206,6 +225,12 @@ define(['require',
                     fetchSaveSearchCollection();
                 });
             },
+            renderRelationshipSearchView: function() {
+                var that = this;
+                require(['views/search/RelationSearchLayoutView'], function(RelationSearchLayoutView) {
+                    that.RRelationSearch.show(new RelationSearchLayoutView(that.options));
+                });
+            },
             bindEvents: function(param) {
                 var that = this;
                 this.listenTo(this.typeHeaders, "reset", function(value) {
@@ -231,6 +256,13 @@ define(['require',
                     this.setInitialEntityVal = false;
                 }
             },
+            disableRefreshButton: function() {
+                var that = this;
+                this.ui.refreshBtn.attr('disabled', true);
+                setTimeout(function() {
+                    that.ui.refreshBtn.attr('disabled', false);
+                }, 1000);
+            },
             makeFilterButtonActive: function(filtertypeParam) {
                 var filtertype = ['entityFilters', 'tagFilters'],
                     that = this;
@@ -359,6 +391,14 @@ define(['require',
             onRender: function() {
                 // array of tags which is coming from url
                 this.initializeValues();
+                this.updateTabState();
+            },
+            updateTabState: function() {
+                if ((Utils.getUrlState.isRelationTab() || Utils.getUrlState.isRelationshipDetailPage()) && !this.isRelationSearch) {
+                    var tabActive = (Utils.getUrlState.isRelationTab() || Utils.getUrlState.isRelationshipDetailPage()) ? "relationship-search" : "basic-search";
+                    this.$('.nav.nav-tabs').find('[role="' + tabActive + '"]').addClass('active').siblings().removeClass('active');
+                    this.$('.tab-content').find('[role="' + tabActive + '"]').addClass('active').siblings().removeClass('active');
+                }
             },
             updateQueryObject: function(param) {
                 if (param && param.searchType) {
@@ -384,6 +424,7 @@ define(['require',
                     }), param);
             },
             onRefreshButton: function() {
+                this.disableRefreshButton();
                 var that = this,
                     apiCount = 2,
                     updateSearchList = function() {
@@ -532,7 +573,7 @@ define(['require',
                 });
 
                 _.each(_.uniq(serviceArr), function(service) {
-                    serviceStr += '<li><div class="pretty p-switch p-fill"><input type="checkbox" class="pull-left" data-value="' + (service) + '" value="" ' + (_.contains(that.selectedFilter[that.type], service) ? "checked" : "") + '/><div class="state p-primary"><label>' + (service.toUpperCase()) + '</label></div></div></li>';
+                    serviceStr += '<li><div class="pretty p-switch p-fill"><input type="checkbox" class="pull-left" data-value="' + (service) + '" value="" ' + (_.contains(that.filterTypeSelected, service) ? "checked" : "") + '/><div class="state p-primary"><label>' + (service.toUpperCase()) + '</label></div></div></li>';
                 });
                 var templt = serviceStr + '<hr class="hr-filter"/><div class="text-right"><div class="divider"></div><button class="btn btn-action btn-sm filterDone">Done</button></div>';
                 return templt;
@@ -609,14 +650,18 @@ define(['require',
                     getFilterBox: this.getFilterBox.bind(this),
                     onFilterSubmit: function(options) {
                         that.selectedFilter[that.type] = options.filterVal;
-                        that.renderTypeTagList({ "filterList": options.filterVal, isTypeOnly: true })
+                        that.filterTypeSelected = that.selectedFilter[that.type];
+                        that.renderTypeTagList({ "filterList": options.filterVal, isTypeOnly: true });
+                        that.checkForButtonVisiblity();
                     }
                 });
-                typeLovSelect2.on("select2:close", function() {
-                    typeLovSelect2.trigger("hideFilter");
-                });
-                if (typeLovSelect2 && isTypeOnly) {
-                    typeLovSelect2.select2('open').trigger("change", { 'manual': true });
+                if (this.value.filterTypeSelected === "undefined") {
+                    typeLovSelect2.on("select2:close", function() {
+                        typeLovSelect2.trigger("hideFilter");
+                    });
+                    if (typeLovSelect2 && isTypeOnly) {
+                        typeLovSelect2.select2('open').trigger("change", { 'manual': true });
+                    }
                 }
                 if (that.setInitialEntityVal) {
                     var defaultEntity = Enums.addOnEntities[0];
@@ -683,9 +728,14 @@ define(['require',
                 if (paramObj) {
                     this.value = paramObj;
                 }
+                if (this.value.filterTypeSelected) {
+                    this.filterTypeSelected = this.value.filterTypeSelected.split(',');
+                    this.renderTypeTagList({ "filterList": this.filterTypeSelected, isTypeOnly: true });
+                    this.ui.typeLov.val(this.value.type);
+                }
                 if (this.value) {
                     this.ui.searchInput.val(this.value.query || "");
-                    if (this.value.dslChecked == "true") {
+                    if (this.value.dslChecked == "true" || this.value.searchType === "dsl") {
                         if (!this.ui.searchType.prop("checked")) {
                             this.ui.searchType.prop("checked", true).trigger("change");
                         }
@@ -736,6 +786,7 @@ define(['require',
             },
             findSearchResult: function() {
                 this.triggerSearch(this.ui.searchInput.val());
+                Globals.fromRelationshipSearch = false;
             },
             //This below function returns the searched Term Guid.
             getSearchedTermGuid: function() {
@@ -754,7 +805,8 @@ define(['require',
                         searchType: this.type,
                         dslChecked: this.ui.searchType.is(':checked'),
                         tagFilters: null,
-                        entityFilters: null
+                        entityFilters: null,
+                        filterTypeSelected: this.filterTypeSelected
                     },
                     typeLovValue = this.ui.typeLov.find(':selected').data('name'), // to get count of selected element used data
                     tagLovValue = this.ui.tagLov.find(':selected').data('name') || this.ui.tagLov.val(),
@@ -777,9 +829,7 @@ define(['require',
                             params['entityFilters'] = entityFilterObj[this.value.type]
                         }
                         var columnList = this.value.type && this.searchTableColumns ? this.searchTableColumns[this.value.type] : null;
-                        if (columnList) {
-                            params['attributes'] = columnList.join(',');
-                        }
+                        params['attributes'] = columnList ? columnList.join(',') : null;
                         params['includeDE'] = _.isUndefinedNull(this.value.includeDE) ? false : this.value.includeDE;
                         params['excludeST'] = _.isUndefinedNull(this.value.excludeST) ? false : this.value.excludeST;
                         params['excludeSC'] = _.isUndefinedNull(this.value.excludeSC) ? false : this.value.excludeSC;
@@ -844,6 +894,7 @@ define(['require',
             },
             clearSearchData: function() {
                 this.selectedFilter[this.type] = [];
+                this.filterTypeSelected = [];
                 this.renderTypeTagList();
                 this.updateQueryObject();
                 this.ui.typeLov.val("").trigger("change");
