@@ -70,7 +70,9 @@ define(['require',
                 showPage: "[data-id='showPage']",
                 gotoPage: "[data-id='gotoPage']",
                 gotoPagebtn: "[data-id='gotoPagebtn']",
-                activePage: "[data-id='activePage']"
+                activePage: "[data-id='activePage']",
+                excludeSubtypes: ".exclude-subtypes",
+                excludeSubClassifications: ".exclude-subclassifications"
             },
             templateHelpers: function() {
                 return {
@@ -91,7 +93,7 @@ define(['require',
                         this.onClickTagCross(e);
                     } else {
                         this.triggerUrl({
-                            url: '#!/tag/tagAttribute/' + scope.text(),
+                            url: '#!/tag/tagAttribute/' + scope.text().split('@')[0],
                             urlParams: null,
                             mergeBrowserUrl: false,
                             trigger: true,
@@ -154,6 +156,7 @@ define(['require',
                 this.offset = 0;
                 this.bindEvents();
                 this.multiSelectEntity = [];
+                this.activeEntityCountSelected = 0;
                 this.searchType = 'Basic Search';
                 this.columnOrder = null;
                 this.defaultColumns = ["selected", "name", "description", "typeName", "owner", "tag", "term"];
@@ -189,6 +192,7 @@ define(['require',
                 this.onClickLoadMore();
                 this.listenTo(this.searchCollection, 'backgrid:selected', function(model, checked) {
                     this.multiSelectEntity = [];
+                    that.activeEntityCountSelected = 0;
                     if (checked === true) {
                         model.set("isEnable", true);
                     } else {
@@ -197,6 +201,9 @@ define(['require',
                     this.searchCollection.find(function(item) {
                         if (item.get('isEnable')) {
                             var obj = item.toJSON();
+                            if (item.get('status') === 'ACTIVE') {
+                                that.activeEntityCountSelected++;
+                            }
                             that.multiSelectEntity.push({
                                 id: obj.guid,
                                 model: obj
@@ -207,8 +214,14 @@ define(['require',
                 });
                 this.listenTo(this.searchCollection, "error", function(model, response) {
                     this.hideLoader({ type: 'error' });
+                    if (response.readyState === 0) {
+                        Utils.notifyError({
+                            content: "Request aborted"
+                        });
+                        return;
+                    }
                     var responseJSON = response && response.responseJSON ? response.responseJSON : null,
-                        errorText = (responseJSON && (responseJSON.errorMessage || responseJSON.message || responseJSON.error)) || 'Invalid Expression';
+                        errorText = (responseJSON && (responseJSON.errorMessage || responseJSON.message || responseJSON.error || responseJSON.msgDesc)) || 'Something went wrong';
                     if (errorText) {
                         Utils.notifyError({
                             content: errorText
@@ -237,6 +250,7 @@ define(['require',
                     }
                 }, this);
                 this.listenTo(this.searchVent, "search:refresh", function(model, response) {
+                    this.updateColumnList();
                     this.fetchCollection();
                 }, this);
                 this.listenTo(this.searchCollection, "backgrid:sorted", function(model, response) {
@@ -342,10 +356,11 @@ define(['require',
                 }, options));
             },
             updateMultiSelect: function() {
-                if (this.multiSelectEntity.length > 0) {
-                    this.$('.multiSelectTag,.multiSelectTerm').show();
+                var addTermTagButton = this.$('.multiSelectTag,.multiSelectTerm');
+                if (this.activeEntityCountSelected > 0) {
+                    addTermTagButton.show();
                 } else {
-                    this.$('.multiSelectTag,.multiSelectTerm').hide();
+                    addTermTagButton.hide();
                 }
             },
             updateColumnList: function(updatedList) {
@@ -359,11 +374,11 @@ define(['require',
                     });
                     listOfColumns = _.sortBy(listOfColumns);
                     this.value.attributes = listOfColumns.length ? listOfColumns.join(",") : null;
-                    if (this.value && this.value.type && this.searchTableColumns) {
-                        this.searchTableColumns[this.value.type] = listOfColumns.length ? listOfColumns : null;
+                    if (this.value && (this.value.type || this.value.tag) && this.searchTableColumns) {
+                        this.searchTableColumns[this.value.type || this.value.tag] = listOfColumns.length ? listOfColumns : null;
                     }
-                } else if (this.value && this.value.type && this.searchTableColumns && this.value.attributes) {
-                    this.searchTableColumns[this.value.type] = this.value.attributes.split(",");
+                } else if (this.value && (this.value.type || this.value.tag) && this.searchTableColumns && this.value.attributes) {
+                    this.searchTableColumns[this.value.type || this.value.tag] = this.value.attributes.split(",");
                 }
             },
             fetchCollection: function(value, options) {
@@ -372,13 +387,15 @@ define(['require',
                     isSearchTab = Utils.getUrlState.isSearchTab(),
                     tagFilters = null,
                     entityFilters = null;
+                that.activeEntityCountSelected = 0;
+                that.updateMultiSelect();
                 if (isSearchTab) {
                     tagFilters = CommonViewFunction.attributeFilter.generateAPIObj(this.value.tagFilters);
                     entityFilters = CommonViewFunction.attributeFilter.generateAPIObj(this.value.entityFilters);
                 }
 
                 if (isPostMethod && isSearchTab) {
-                    var excludeDefaultColumn = this.value.type && this.searchTableColumns ? _.difference(this.searchTableColumns[this.value.type], this.defaultColumns) : null,
+                    var excludeDefaultColumn = ((this.value.type || this.value.tag) && this.searchTableColumns) ? _.difference(this.searchTableColumns[this.value.type || this.value.tag], this.defaultColumns) : null,
                         filterObj = {
                             'entityFilters': entityFilters,
                             'tagFilters': tagFilters,
@@ -485,7 +502,6 @@ define(['require',
                         that.ui.activePage.text(that.activePage);
                         that.renderTableLayoutView();
                         that.multiSelectEntity = [];
-                        that.updateMultiSelect();
 
                         if (dataLength > 0) {
                             that.$('.searchTable').removeClass('noData')
@@ -608,6 +624,15 @@ define(['require',
                     that.REntityTableLayoutView.$el.find('.colSort thead tr th:not(.select-all-header-cell)').addClass('dragHandler');
                     tableDragger(document.querySelector(".colSort"), { dragHandler: ".dragHandler" }).on('drop', tableDropFunction);
                 }
+                if (Utils.getUrlState.isGlossaryTab()) {
+                    this.ui.excludeSubtypes.hide();
+                    this.ui.excludeSubClassifications.hide();
+                } else if (this.fromView !== "classification") {
+                    this.ui.excludeSubtypes.show();
+                    this.ui.excludeSubClassifications.show();
+                } else {
+                    this.ui.excludeSubtypes.hide();
+                }
             },
             renderTableLayoutView: function(col) {
                 var that = this;
@@ -653,8 +678,8 @@ define(['require',
                     columnToShow = null,
                     col = {};
                 this.value = this.fromView === "glossary" ? this.value : Utils.getUrlState.getQueryParams() || this.value;
-                if (this.value && this.value.searchType === "basic" && this.searchTableColumns && (this.searchTableColumns[this.value.type] !== undefined)) {
-                    columnToShow = this.searchTableColumns[this.value.type] == null ? [] : this.searchTableColumns[this.value.type];
+                if (this.value && this.value.searchType === "basic" && this.searchTableColumns && (this.searchTableColumns[this.value.type || this.value.tag] !== undefined)) {
+                    columnToShow = this.searchTableColumns[this.value.type || this.value.tag] == null ? [] : this.searchTableColumns[this.value.type || this.value.tag];
                 }
                 col['Check'] = {
                     name: "selected",
@@ -1015,9 +1040,9 @@ define(['require',
                                     return
                                 }
                                 if (obj.status && Enums.entityStateReadOnly[obj.status]) {
-                                    return '<div class="readOnly">' + CommonViewFunction.tagForTable(obj); + '</div>';
+                                    return '<div class="readOnly">' + CommonViewFunction.tagForTable(obj, that.classificationDefCollection); + '</div>';
                                 } else {
-                                    return CommonViewFunction.tagForTable(obj);
+                                    return CommonViewFunction.tagForTable(obj, that.classificationDefCollection);
                                 }
 
                             }
@@ -1057,15 +1082,15 @@ define(['require',
                     };
                 }
             },
-            addTagModalView: function(guid, multiple) {
+            addTagModalView: function(guid, multiple, entityCount) {
                 var that = this;
                 require(['views/tag/AddTagModalView'], function(AddTagModalView) {
                     var view = new AddTagModalView({
                         guid: guid,
                         multiple: multiple,
+                        entityCount: entityCount,
                         callback: function() {
                             that.multiSelectEntity = [];
-                            that.$('.multiSelectTag,.multiSelectTerm').hide();
                             that.fetchCollection();
                             if (that.searchVent) {
                                 that.searchVent.trigger('entityList:refresh');
@@ -1116,7 +1141,7 @@ define(['require',
                     that = this,
                     isTagMultiSelect = $(e.currentTarget).hasClass('multiSelectTag');
                 if (isTagMultiSelect && this.multiSelectEntity && this.multiSelectEntity.length) {
-                    that.addTagModalView(guid, this.multiSelectEntity);
+                    that.addTagModalView(guid, this.multiSelectEntity, this.activeEntityCountSelected);
                 } else {
                     guid = that.$(e.currentTarget).data("guid");
                     that.addTagModalView(guid);
@@ -1139,7 +1164,6 @@ define(['require',
                             associatedTerms: obj.associatedTerms,
                             callback: function() {
                                 that.multiSelectEntity = [];
-                                that.$('.multiSelectTag,.multiSelectTerm').hide();
                                 that.fetchCollection();
                             },
                             glossaryCollection: glossaryCollection,
@@ -1271,7 +1295,7 @@ define(['require',
                 }
                 if (this.value) {
                     this.value[val] = flag;
-                    this.triggerUrl();
+                    this.triggerUrl({ mergeBrowserUrl: true });
                 }
                 _.extend(this.searchCollection.queryParams, { limit: this.limit, offset: this.offset });
                 this.fetchCollection();
