@@ -403,7 +403,7 @@ define(['require',
                         }).open();
                     modal.$el.find('button.ok').attr("disabled", "true");
                     view.ui.tagName.on('keyup input', function(e) {
-                        view.ui.description.val($(this).val().replace(/\s+/g, ' '));
+                        $(view.ui.description).trumbowyg('html', _.escape($(this).val()).replace(/\s+/g, ' '));
                     });
                     view.ui.description.on('input keydown', function(e) {
                         $(this).val($(this).val().replace(/\s+/g, ' '));
@@ -448,7 +448,7 @@ define(['require',
                     return;
                 }
                 this.name = ref.ui.tagName.val();
-                this.description = ref.ui.description.val();
+                this.description = Utils.sanitizeHtmlContent({ data: ref.ui.description.val() });
                 var superTypes = [];
                 if (ref.ui.parentTag.val() && ref.ui.parentTag.val()) {
                     superTypes = ref.ui.parentTag.val();
@@ -651,6 +651,9 @@ define(['require',
                     },
                     cust_error: function() {},
                     complete: function() {
+                        if (that.collection.fullCollection.length === 0) {
+                            that.setUrl('#!/tag', true);
+                        }
                         that.notificationModal.hideButtonLoader();
                         that.notificationModal.remove();
                     }
