@@ -162,6 +162,13 @@ require.config({
         },
         'jquery-steps': {
             'deps': ['jquery']
+        },
+        'DOMPurify': {
+            'exports': 'DOMPurify'
+        },
+        'trumbowyg': {
+            'deps': ['jquery'],
+            'exports': 'trumbowyg'
         }
     },
 
@@ -207,7 +214,10 @@ require.config({
         'jstree': 'libs/jstree/jstree.min',
         'jquery-steps': 'libs/jquery-steps/jquery.steps.min',
         'dropzone': 'libs/dropzone/js/dropzone-amd-module',
-        'lossless-json': 'libs/lossless-json/lossless-json'
+        'lossless-json': 'libs/lossless-json/lossless-json',
+        'store': 'external_lib/idealTimeout/store.min',
+        'DOMPurify': 'external_lib/dompurify/purify.min',
+        'trumbowyg': 'external_lib/trumbowyg/trumbowyg'
     },
 
     /**
@@ -227,12 +237,14 @@ require(['App',
     'utils/UrlLinks',
     'collection/VEntityList',
     'collection/VTagList',
+    'collection/VRelationshipSearchList',
     'utils/Enums',
+    'utils/Utils',
     'utils/Overrides',
     'bootstrap',
     'd3',
     'select2'
-], function(App, Router, Helper, CommonViewFunction, Globals, UrlLinks, VEntityList, VTagList, Enums) {
+], function(App, Router, Helper, CommonViewFunction, Globals, UrlLinks, VEntityList, VTagList, VRelationshipSearchList, Enums, Utils) {
     var that = this;
     this.asyncFetchCounter = 5 + (Enums.addOnEntities.length + 1);
     // entity
@@ -256,6 +268,10 @@ require(['App',
     this.businessMetadataDefCollection = new VEntityList();
     this.businessMetadataDefCollection.url = UrlLinks.businessMetadataDefApiUrl();
     this.businessMetadataDefCollection.modelAttrName = "businessMetadataDefs";
+    //relationship
+    this.relationshipDefCollection = new VRelationshipSearchList();
+    this.relationshipDefCollection.url = UrlLinks.relationshipDefApiUrl();
+    this.relationshipDefCollection.modelAttrName = "relationshipDefs";
 
     App.appRouter = new Router({
         entityDefCollection: this.entityDefCollection,
@@ -264,7 +280,8 @@ require(['App',
         classificationDefCollection: this.classificationDefCollection,
         metricCollection: this.metricCollection,
         classificationAndMetricEvent: this.classificationAndMetricEvent,
-        businessMetadataDefCollection: this.businessMetadataDefCollection
+        businessMetadataDefCollection: this.businessMetadataDefCollection,
+        relationshipDefCollection: this.relationshipDefCollection
     });
 
     var startApp = function() {
@@ -315,6 +332,33 @@ require(['App',
                 if (response['atlas.tasks.enabled'] !== undefined) {
                     Globals.isTasksEnabled = response['atlas.tasks.enabled'];
                 }
+                if (response['atlas.session.timeout.secs']) { Globals.idealTimeoutSeconds = response['atlas.session.timeout.secs']; }
+                if(response['atlas.lineage.on.demand.enabled'] !== undefined){
+                    Globals.isLineageOnDemandEnabled = response['atlas.lineage.on.demand.enabled'];
+                }
+                if(response['atlas.lineage.on.demand.default.node.count'] !== undefined){
+                    Globals.lineageNodeCount = response['atlas.lineage.on.demand.default.node.count'];
+                }
+                /*  Atlas idealTimeout 
+       redirectUrl: url to redirect after timeout
+       idealTimeLimit: timeout in seconds
+       activityEvents: ideal keyboard mouse events
+       dialogDisplayLimit: show popup before timeout in seconds
+       */
+                $(document).ready(function() {
+                    $(document).idleTimeout({
+                        redirectUrl: Utils.getBaseUrl(window.location.pathname) + '/index.html?action=timeout', // redirect to this url
+                        idleTimeLimit: Globals.idealTimeoutSeconds, // 900 seconds
+                        activityEvents: 'click keypress scroll wheel mousemove', // separate each event with a space
+                        dialogDisplayLimit: 10, // Time to display the warning dialog before logout (and optional callback) in seconds
+                        sessionKeepAliveTimer: false, // Set to false to disable pings.
+                        onModalKeepAlive: function() {
+                            CommonViewFunction.userDataFetch({
+                                url: UrlLinks.sessionApiUrl()
+                            })
+                        }
+                    });
+                });
             }
             --that.asyncFetchCounter;
             startApp();
@@ -380,6 +424,16 @@ require(['App',
             startApp();
         }
     });
+    this.relationshipDefCollection.fetch({
+        async:true,
+        complete: function() {
+            that.relationshipDefCollection.fullCollection.comparator = function(model) {
+                return model.get('name').toLowerCase();
+            };
+            that.relationshipDefCollection.fullCollection.sort({ silent: true });
+            startApp();
+        }
+    });
     CommonViewFunction.fetchRootEntityAttributes({
         url: UrlLinks.rootEntityDefUrl(Enums.addOnEntities[0]),
         entity: Enums.addOnEntities,
