@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums', 'moment', 'moment-timezone', 'pnotify.buttons', 'pnotify.confirm'], function(require, Globals, pnotify, Messages, Enums, moment) {
+define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums', 'moment', 'store', 'modules/Modal', 'DOMPurify', 'moment-timezone', 'pnotify.buttons', 'pnotify.confirm', 'trumbowyg'], function(require, Globals, pnotify, Messages, Enums, moment, store, Modal, DOMPurify) {
     'use strict';
 
     var Utils = {};
@@ -355,6 +355,8 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
                     urlUpdate['administratorUrl'] = options.url;
                 } else if (Utils.getUrlState.isDebugMetricsTab(options.url)) {
                     urlUpdate['debugMetricsUrl'] = options.url;
+                } else if (Utils.getUrlState.isRelationTab(options.url)) {
+                    urlUpdate['relationUrl'] = options.url;
                 }
                 $.extend(Globals.saveApplicationState.tabState, urlUpdate);
             }
@@ -396,6 +398,18 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
                 matchString: "search"
             });
         },
+        isRelationTab: function(url) {
+            return this.checkTabUrl({
+                url: url,
+                matchString: "relationship"
+            });
+        },
+        isRelationSearch: function(url) {
+            return this.checkTabUrl({
+                url: url,
+                matchString: "relationship/relationshipSearchResult"
+            });
+        },
         isAdministratorTab: function(url) {
             return this.checkTabUrl({
                 url: url,
@@ -424,6 +438,12 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
                 matchString: "detailPage"
             });
         },
+        isRelationshipDetailPage: function(url) {
+            return this.checkTabUrl({
+                url: url,
+                matchString: "relationshipDetailPage"
+            });
+        },
         getLastValue: function() {
             return this.getQueryUrl().lastValue;
         },
@@ -584,6 +604,9 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
                 urlPath = "administratorUrl";
             }
         }
+        if (Globals.fromRelationshipSearch) {
+            urlPath = 'relationUrl';
+        }
         Utils.setUrl({
             url: Globals.saveApplicationState.tabState[urlPath],
             mergeBrowserUrl: false,
@@ -964,5 +987,334 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
         }
         return dateValue;
     }
+
+    //------------------------------------------------idleTimeout-----------------------------
+    $.fn.idleTimeout = function(userRuntimeConfig) {
+
+        //##############################
+        //## Public Configuration Variables
+        //##############################
+        var defaultConfig = {
+                redirectUrl: Utils.getBaseUrl(window.location.pathname) + '/index.html?action=timeout', // redirect to this url on logout. Set to "redirectUrl: false" to disable redirect
+
+                // idle settings
+                idleTimeLimit: Globals.idealTimeoutSeconds, // 'No activity' time limit in seconds. 1200 = 20 Minutes
+                idleCheckHeartbeat: 2, // Frequency to check for idle timeouts in seconds
+
+                // optional custom callback to perform before logout
+                customCallback: false, // set to false for no customCallback
+                // customCallback:    function () {    // define optional custom js function
+                // perform custom action before logout
+                // },
+
+                // configure which activity events to detect
+                // http://www.quirksmode.org/dom/events/
+                // https://developer.mozilla.org/en-US/docs/Web/Reference/Events
+                activityEvents: 'click keypress scroll wheel mousewheel mousemove', // separate each event with a space
+
+                // warning dialog box configuration
+                enableDialog: true, // set to false for logout without warning dialog
+                dialogDisplayLimit: 10, // Time to display the warning dialog before logout (and optional callback) in seconds. 180 = 3 Minutes
+                dialogTitle: 'Your session is about to expire!', // also displays on browser title bar
+                dialogText: 'Your session is about to expire.',
+                dialogTimeRemaining: 'You will be logged out in ',
+                dialogStayLoggedInButton: 'Stay Logged In',
+                dialogLogOutNowButton: 'Logout',
+
+                // error message if https://github.com/marcuswestin/store.js not enabled
+                errorAlertMessage: 'Please disable "Private Mode", or upgrade to a modern browser. Or perhaps a dependent file missing. Please see: https://github.com/marcuswestin/store.js',
+
+                // server-side session keep-alive timer
+                sessionKeepAliveTimer: 600, // ping the server at this interval in seconds. 600 = 10 Minutes. Set to false to disable pings
+                sessionKeepAliveUrl: window.location.href // set URL to ping - does not apply if sessionKeepAliveTimer: false
+            },
+
+            //##############################
+            //## Private Variables
+            //##############################
+            currentConfig = $.extend(defaultConfig, userRuntimeConfig), // merge default and user runtime configuration
+            origTitle = document.title, // save original browser title
+            activityDetector,
+            startKeepSessionAlive, stopKeepSessionAlive, keepSession, keepAlivePing, // session keep alive
+            idleTimer, remainingTimer, checkIdleTimeout, checkIdleTimeoutLoop, startIdleTimer, stopIdleTimer, // idle timer
+            openWarningDialog, dialogTimer, checkDialogTimeout, startDialogTimer, stopDialogTimer, isDialogOpen, destroyWarningDialog, countdownDisplay, // warning dialog
+            logoutUser;
+
+        //##############################
+        //## Public Functions
+        //##############################
+        // trigger a manual user logout
+        // use this code snippet on your site's Logout button: $.fn.idleTimeout().logout();
+        this.logout = function() {
+            store.set('idleTimerLoggedOut', true);
+        };
+
+        //##############################
+        //## Private Functions
+        //##############################
+
+        //----------- KEEP SESSION ALIVE FUNCTIONS --------------//
+        startKeepSessionAlive = function() {
+
+            keepSession = function() {
+                $.get(currentConfig.sessionKeepAliveUrl);
+                startKeepSessionAlive();
+            };
+
+            keepAlivePing = setTimeout(keepSession, (currentConfig.sessionKeepAliveTimer * 1000));
+        };
+
+        stopKeepSessionAlive = function() {
+            clearTimeout(keepAlivePing);
+        };
+
+        //----------- ACTIVITY DETECTION FUNCTION --------------//
+        activityDetector = function() {
+
+            $('body').on(currentConfig.activityEvents, function() {
+
+                if (!currentConfig.enableDialog || (currentConfig.enableDialog && isDialogOpen() !== true)) {
+                    startIdleTimer();
+                    $('#activity').effect('shake'); // added for demonstration page
+                }
+            });
+        };
+
+        //----------- IDLE TIMER FUNCTIONS --------------//
+        checkIdleTimeout = function() {
+
+            var timeIdleTimeout = (store.get('idleTimerLastActivity') + (currentConfig.idleTimeLimit * 1000));
+
+            if ($.now() > timeIdleTimeout) {
+
+                if (!currentConfig.enableDialog) { // warning dialog is disabled
+                    logoutUser(); // immediately log out user when user is idle for idleTimeLimit
+                } else if (currentConfig.enableDialog && isDialogOpen() !== true) {
+                    openWarningDialog();
+                    startDialogTimer(); // start timing the warning dialog
+                }
+            } else if (store.get('idleTimerLoggedOut') === true) { //a 'manual' user logout?
+                logoutUser();
+            } else {
+
+                if (currentConfig.enableDialog && isDialogOpen() === true) {
+                    destroyWarningDialog();
+                    stopDialogTimer();
+                }
+            }
+        };
+
+        startIdleTimer = function() {
+            stopIdleTimer();
+            store.set('idleTimerLastActivity', $.now());
+            checkIdleTimeoutLoop();
+        };
+
+        checkIdleTimeoutLoop = function() {
+            checkIdleTimeout();
+            idleTimer = setTimeout(checkIdleTimeoutLoop, (currentConfig.idleCheckHeartbeat * 1000));
+        };
+
+        stopIdleTimer = function() {
+            clearTimeout(idleTimer);
+        };
+
+        //----------- WARNING DIALOG FUNCTIONS --------------//
+        openWarningDialog = function() {
+
+
+            var dialogContent = "<div id='idletimer_warning_dialog'><p>" + currentConfig.dialogText + "</p><p style='display:inline'>" + currentConfig.dialogTimeRemaining + ": <div style='display:inline' id='countdownDisplay'></div> secs.</p></div>";
+
+            var that = this,
+                modalObj = {
+                    title: currentConfig.dialogTitle,
+                    htmlContent: dialogContent,
+                    okText: "Stay Signed-in",
+                    cancelText: 'Logout',
+                    mainClass: 'modal-lg',
+                    allowCancel: true,
+                    okCloses: false,
+                    escape: false,
+                    cancellable: true,
+                    width: "500px",
+                    mainClass: "ideal-timeout"
+                };
+            var modal = new Modal(modalObj);
+            modal.open();
+            modal.on('ok', function() {
+                if (userRuntimeConfig && userRuntimeConfig.onModalKeepAlive) {
+                    userRuntimeConfig.onModalKeepAlive(); //hit session API
+                }
+                destroyWarningDialog();
+                modal.close();
+                stopDialogTimer();
+                startIdleTimer();
+            });
+            modal.on('closeModal', function() {
+                logoutUser();
+            });
+
+            countdownDisplay();
+
+            // document.title = currentConfig.dialogTitle;
+
+            if (currentConfig.sessionKeepAliveTimer) {
+                stopKeepSessionAlive();
+            }
+        };
+
+        checkDialogTimeout = function() {
+            var timeDialogTimeout = (store.get('idleTimerLastActivity') + (currentConfig.idleTimeLimit * 1000) + (currentConfig.dialogDisplayLimit * 1000));
+
+            if (($.now() > timeDialogTimeout) || (store.get('idleTimerLoggedOut') === true)) {
+                logoutUser();
+            }
+        };
+
+        startDialogTimer = function() {
+            dialogTimer = setInterval(checkDialogTimeout, (currentConfig.idleCheckHeartbeat * 1000));
+        };
+
+        stopDialogTimer = function() {
+            clearInterval(dialogTimer);
+            clearInterval(remainingTimer);
+        };
+
+        isDialogOpen = function() {
+            var dialogOpen = $("#idletimer_warning_dialog").is(":visible");
+
+            if (dialogOpen === true) {
+                return true;
+            }
+            return false;
+        };
+
+        destroyWarningDialog = function() {
+            if (currentConfig.sessionKeepAliveTimer) {
+                startKeepSessionAlive();
+            }
+        };
+
+        countdownDisplay = function() {
+            var dialogDisplaySeconds = currentConfig.dialogDisplayLimit,
+                mins, secs;
+
+            remainingTimer = setInterval(function() {
+                mins = Math.floor(dialogDisplaySeconds / 60); // minutes
+                if (mins < 10) { mins = '0' + mins; }
+                secs = dialogDisplaySeconds - (mins * 60); // seconds
+                if (secs < 10) { secs = '0' + secs; }
+                $('#countdownDisplay').html(mins + ':' + secs);
+                dialogDisplaySeconds -= 1;
+            }, 1000);
+        };
+
+        //----------- LOGOUT USER FUNCTION --------------//
+        logoutUser = function() {
+            store.set('idleTimerLoggedOut', true);
+
+            if (currentConfig.sessionKeepAliveTimer) {
+                stopKeepSessionAlive();
+            }
+
+            if (currentConfig.customCallback) {
+                currentConfig.customCallback();
+            }
+
+            if (currentConfig.redirectUrl) {
+                window.location.href = currentConfig.redirectUrl;
+            }
+        };
+
+        //###############################
+        // Build & Return the instance of the item as a plugin
+        // This is your construct.
+        //###############################
+        return this.each(function() {
+
+            if (store.enabled) {
+
+                store.set('idleTimerLastActivity', $.now());
+                store.set('idleTimerLoggedOut', false);
+
+                activityDetector();
+
+                if (currentConfig.sessionKeepAliveTimer) {
+                    startKeepSessionAlive();
+                }
+
+                startIdleTimer();
+
+            } else {
+                alert(currentConfig.errorAlertMessage);
+            }
+
+        });
+    };
+
+    //------------------------------------------------
+
+    //--------------------------------------Custom Text Editor-----------------------------------//
+    Utils.addCustomTextEditor = function(options) {
+        var selector = options.selector ? options.selector : ".customTextEditor",
+            defaultBtns = [
+                ['formatting'],
+                ['strong', 'em', 'underline', 'del'],
+                ['link'],
+                ['unorderedList', 'orderedList'],
+                ['viewHTML']
+            ],
+            smallTextEditorBtn = [
+                ['strong', 'em', 'underline', 'del'],
+                ['link'],
+                ['unorderedList', 'orderedList'],
+            ],
+            customBtnDefs = {
+                formatting: {
+                    dropdown: ['p', 'h1', 'h2', 'h3', 'h4'],
+                    ico: 'p'
+                }
+            },
+            $btnPane, $parent;
+        $(selector).trumbowyg({
+            btns: options.small ? smallTextEditorBtn : defaultBtns,
+            autogrow: true,
+            removeformatPasted: true,
+            urlProtocol: true,
+            defaultLinkTarget: '_blank',
+            btnsDef: options.small ? {} : customBtnDefs
+        }).on('tbwinit', function() {
+            $btnPane = $(this).parent().find('.trumbowyg-button-pane');
+            $parent = $(this).parent();
+            if (options.small) {
+                $parent.addClass('small-texteditor');
+            }
+            if (!options.initialHide) {
+                $btnPane.addClass('trumbowyg-button-pane-hidden');
+                $parent.css('border', '1px solid #e8e9ee');
+            }
+        }).on('tbwblur', function(e) {
+            $btnPane.addClass('trumbowyg-button-pane-hidden');
+            $parent.css('border', '1px solid #e8e9ee');
+        }).on('tbwfocus', function(e) {
+            $btnPane.removeClass('trumbowyg-button-pane-hidden');
+            $parent.css('border', '1px solid #8fa5b1');
+        }).on('tbwchange', function(e) {
+            options.callback ? options.callback(e) : null;
+        }).on('tbwmodalopen', function(e) {
+            $('input[name="title"], input[name="target"]').parent().css('display', 'none');
+        });
+    }
+
+    Utils.sanitizeHtmlContent = function(options) {
+        var editorContent, cleanedContent;
+        editorContent = options.selector ? $(options.selector).trumbowyg('html') : options.data;
+        if (options && editorContent) {
+            cleanedContent = DOMPurify.sanitize(editorContent, { FORBID_TAGS: ['img', 'script', 'iframe', 'embed', 'svg', 'meta'], ALLOWED_ATTR: ['target', 'href'] });
+        }
+        return cleanedContent;
+    }
+    //-----------------------------------------END---------------------//
+
     return Utils;
-});
\ No newline at end of file
+});
