@@ -138,6 +138,7 @@ define(['require',
                 }
                 if (this.isAssignView && this.glossaryCollection.fullCollection.length) {
                     this.generateTree();
+                    this.disableNodesList = this.getDisableNodes();
                 } else {
                     this.getGlossary();
                 }
@@ -409,6 +410,17 @@ define(['require',
                     this.triggerUrl();
                 }
             },
+            getDisableNodes: function() {
+                var disableNodesSelection = [];
+                if (this.options && this.options.isAssignAttributeRelationView) {
+                    var disableTerms = (this.options.termData && this.options.selectedTermAttribute) ? this.options.termData[this.options.selectedTermAttribute] : null;
+                    disableNodesSelection = _.map(disableTerms, function(obj) {
+                        return obj.termGuid;
+                    });
+                    disableNodesSelection.push(this.options.termData.guid);
+                }
+                return disableNodesSelection;
+            },
             generateTree: function() {
                 var $termTree = this.ui.termTree,
                     $categoryTree = this.ui.categoryTree,
@@ -423,7 +435,11 @@ define(['require',
                                     return;
                                 }
                                 if (that.isAssignView) {
-                                    return obj != "Glossary" ? true : false;
+                                    var isDisableNode = false;
+                                    if (that.disableNodesList) {
+                                        isDisableNode = (that.disableNodesList.indexOf(node.original.guid) > -1) ? true : false;
+                                    }
+                                    return (obj != "Glossary" && !isDisableNode) ? true : false;
                                 } else {
                                     return obj != "NoAction" ? true : false;
                                 }
