@@ -653,9 +653,7 @@ define(['require',
                         params['entityFilters'] = entityFilterObj[this.value.type]
                     }
                     var columnList = this.value && this.value.type && this.searchTableColumns ? this.searchTableColumns[this.value.type] : null;
-                    if (columnList) {
-                        params['attributes'] = columnList.join(',');
-                    }
+                    params['attributes'] = columnList ? columnList.join(',') : null;
                     params['includeDE'] = _.isUndefinedNull(this.value.includeDE) ? false : this.value.includeDE;
                     params['excludeST'] = _.isUndefinedNull(this.value.excludeST) ? false : this.value.excludeST;
                     params['excludeSC'] = _.isUndefinedNull(this.value.excludeSC) ? false : this.value.excludeSC;
