@@ -71,7 +71,9 @@ define(['require',
                 gotoPage: "[data-id='gotoPage']",
                 gotoPagebtn: "[data-id='gotoPagebtn']",
                 activePage: "[data-id='activePage']",
-                saveFilter: "[data-id='saveFilter']"
+                saveFilter: "[data-id='saveFilter']",
+                excludeSubtypes: ".exclude-subtypes",
+                excludeSubClassifications: ".exclude-subclassifications"
             },
             templateHelpers: function() {
                 return {
@@ -92,7 +94,7 @@ define(['require',
                         this.onClickTagCross(e);
                     } else {
                         this.triggerUrl({
-                            url: '#!/tag/tagAttribute/' + scope.text(),
+                            url: '#!/tag/tagAttribute/' + scope.text().split('@')[0],
                             urlParams: null,
                             mergeBrowserUrl: false,
                             trigger: true,
@@ -161,6 +163,7 @@ define(['require',
                 this.offset = 0;
                 this.bindEvents();
                 this.multiSelectEntity = [];
+                this.activeEntityCountSelected = 0;
                 this.searchType = 'Basic Search';
                 this.columnOrder = null;
                 this.defaultColumns = ["selected", "name", "description", "typeName", "owner", "tag", "term"];
@@ -196,6 +199,7 @@ define(['require',
                 this.onClickLoadMore();
                 this.listenTo(this.searchCollection, 'backgrid:selected', function(model, checked) {
                     this.multiSelectEntity = [];
+                    that.activeEntityCountSelected = 0;
                     if (checked === true) {
                         model.set("isEnable", true);
                     } else {
@@ -204,6 +208,9 @@ define(['require',
                     this.searchCollection.find(function(item) {
                         if (item.get('isEnable')) {
                             var obj = item.toJSON();
+                            if (item.get('status') === 'ACTIVE') {
+                                that.activeEntityCountSelected++;
+                            }
                             that.multiSelectEntity.push({
                                 id: obj.guid,
                                 model: obj
@@ -214,8 +221,14 @@ define(['require',
                 });
                 this.listenTo(this.searchCollection, "error", function(model, response) {
                     this.hideLoader({ type: 'error' });
+                    if (response.readyState === 0) {
+                        Utils.notifyError({
+                            content: "Request aborted"
+                        });
+                        return;
+                    }
                     var responseJSON = response && response.responseJSON ? response.responseJSON : null,
-                        errorText = (responseJSON && (responseJSON.errorMessage || responseJSON.message || responseJSON.error)) || 'Invalid Expression';
+                        errorText = (responseJSON && (responseJSON.errorMessage || responseJSON.message || responseJSON.error || responseJSON.msgDesc)) || 'Something went wrong';
                     if (errorText) {
                         Utils.notifyError({
                             content: errorText
@@ -356,10 +369,11 @@ define(['require',
                 }, options));
             },
             updateMultiSelect: function() {
-                if (this.multiSelectEntity.length > 0) {
-                    this.$('.multiSelectTag,.multiSelectTerm').show();
+                var addTermTagButton = this.$('.multiSelectTag,.multiSelectTerm');
+                if (this.activeEntityCountSelected > 0) {
+                    addTermTagButton.show();
                 } else {
-                    this.$('.multiSelectTag,.multiSelectTerm').hide();
+                    addTermTagButton.hide();
                 }
             },
             updateColumnList: function(updatedList) {
@@ -373,11 +387,11 @@ define(['require',
                     });
                     listOfColumns = _.sortBy(listOfColumns);
                     this.value.attributes = listOfColumns.length ? listOfColumns.join(",") : null;
-                    if (this.value && this.value.type && this.searchTableColumns) {
-                        this.searchTableColumns[this.value.type] = listOfColumns.length ? listOfColumns : null;
+                    if (this.value && (this.value.type || this.value.tag) && this.searchTableColumns) {
+                        this.searchTableColumns[this.value.type || this.value.tag] = listOfColumns.length ? listOfColumns : null;
                     }
-                } else if (this.value && this.value.type && this.searchTableColumns && this.value.attributes) {
-                    this.searchTableColumns[this.value.type] = this.value.attributes.split(",");
+                } else if (this.value && (this.value.type || this.value.tag) && this.searchTableColumns && this.value.attributes) {
+                    this.searchTableColumns[this.value.type || this.value.tag] = this.value.attributes.split(",");
                 }
             },
             fetchCollection: function(value, options) {
@@ -386,13 +400,15 @@ define(['require',
                     isSearchTab = Utils.getUrlState.isSearchTab(),
                     tagFilters = null,
                     entityFilters = null;
+                that.activeEntityCountSelected = 0;
+                that.updateMultiSelect();
                 if (isSearchTab) {
                     tagFilters = CommonViewFunction.attributeFilter.generateAPIObj(this.value.tagFilters);
                     entityFilters = CommonViewFunction.attributeFilter.generateAPIObj(this.value.entityFilters);
                 }
 
                 if (isPostMethod && isSearchTab) {
-                    var excludeDefaultColumn = this.value.type && this.searchTableColumns ? _.difference(this.searchTableColumns[this.value.type], this.defaultColumns) : null,
+                    var excludeDefaultColumn = ((this.value.type || this.value.tag) && this.searchTableColumns) ? _.difference(this.searchTableColumns[this.value.type || this.value.tag], this.defaultColumns) : null,
                         filterObj = {
                             'entityFilters': entityFilters,
                             'tagFilters': tagFilters,
@@ -499,7 +515,6 @@ define(['require',
                         that.ui.activePage.text(that.activePage);
                         that.renderTableLayoutView();
                         that.multiSelectEntity = [];
-                        that.updateMultiSelect();
 
                         if (dataLength > 0) {
                             that.$('.searchTable').removeClass('noData')
@@ -624,6 +639,12 @@ define(['require',
                     that.REntityTableLayoutView.$el.find('.colSort thead tr th:not(.select-all-header-cell)').addClass('dragHandler');
                     tableDragger(document.querySelector(".colSort"), { dragHandler: ".dragHandler" }).on('drop', tableDropFunction);
                 }
+                if (Utils.getUrlState.isGlossaryTab()) {
+                    this.ui.excludeSubtypes.hide();
+                    this.ui.excludeSubClassifications.hide();
+                } else {
+                    this.ui.excludeSubtypes.hide();
+                }
             },
             renderTableLayoutView: function(col) {
                 var that = this;
@@ -669,8 +690,8 @@ define(['require',
                     columnToShow = null,
                     col = {};
                 this.value = Utils.getUrlState.getQueryParams() || this.value;
-                if (this.value && this.value.searchType === "basic" && this.searchTableColumns && (this.searchTableColumns[this.value.type] !== undefined)) {
-                    columnToShow = this.searchTableColumns[this.value.type] == null ? [] : this.searchTableColumns[this.value.type];
+                if (this.value && this.value.searchType === "basic" && this.searchTableColumns && (this.searchTableColumns[this.value.type || this.value.tag] !== undefined)) {
+                    columnToShow = this.searchTableColumns[this.value.type || this.value.tag] == null ? [] : this.searchTableColumns[this.value.type || this.value.tag];
                 }
                 col['Check'] = {
                     name: "selected",
@@ -1030,9 +1051,9 @@ define(['require',
                                     return
                                 }
                                 if (obj.status && Enums.entityStateReadOnly[obj.status]) {
-                                    return '<div class="readOnly">' + CommonViewFunction.tagForTable(obj); + '</div>';
+                                    return '<div class="readOnly">' + CommonViewFunction.tagForTable(obj, that.classificationDefCollection); + '</div>';
                                 } else {
-                                    return CommonViewFunction.tagForTable(obj);
+                                    return CommonViewFunction.tagForTable(obj, that.classificationDefCollection);
                                 }
 
                             }
@@ -1072,18 +1093,18 @@ define(['require',
                     };
                 }
             },
-            addTagModalView: function(guid, multiple) {
+            addTagModalView: function(guid, multiple, entityCount) {
                 var that = this;
                 require(['views/tag/AddTagModalView'], function(AddTagModalView) {
                     var view = new AddTagModalView({
                         guid: guid,
                         multiple: multiple,
+                        entityCount: entityCount,
                         callback: function() {
                             if (that.searchVent) {
                                 that.searchVent.trigger("Classification:Count:Update");
                             }
                             that.multiSelectEntity = [];
-                            that.$('.multiSelectTag,.multiSelectTerm').hide();
                             that.fetchCollection();
                         },
                         tagList: that.getTagList(guid, multiple),
@@ -1132,7 +1153,7 @@ define(['require',
                     that = this,
                     isTagMultiSelect = $(e.currentTarget).hasClass('multiSelectTag');
                 if (isTagMultiSelect && this.multiSelectEntity && this.multiSelectEntity.length) {
-                    that.addTagModalView(guid, this.multiSelectEntity);
+                    that.addTagModalView(guid, this.multiSelectEntity, this.activeEntityCountSelected);
                 } else {
                     guid = that.$(e.currentTarget).data("guid");
                     that.addTagModalView(guid);
@@ -1155,7 +1176,6 @@ define(['require',
                             associatedTerms: obj.associatedTerms,
                             callback: function() {
                                 that.multiSelectEntity = [];
-                                that.$('.multiSelectTag,.multiSelectTerm').hide();
                                 that.fetchCollection();
                             },
                             glossaryCollection: glossaryCollection,
