@@ -31,7 +31,7 @@ if __name__ == '__main__':
     try:
         returncode = main()
     except Exception as e:
-        print "Exception in setting up Kafka topics for Atlas: %s" % str(e)
+        print("Exception in setting up Kafka topics for Atlas: %s" % str(e))
         returncode = -1
 
-    sys.exit(returncode)
\ No newline at end of file
+    sys.exit(returncode)
