@@ -173,6 +173,11 @@ public interface AtlasGraphManagement {
      */
     void updateUniqueIndexesForConsistencyLock();
 
+    /**
+     * update valid SchemaStatus for all vertex and edge indexes.
+     */
+    void updateSchemaStatus();
+
     /***
      * Re-index elements.
      * @param indexName: Name of the index that needs to be operated on.
@@ -180,4 +185,23 @@ public interface AtlasGraphManagement {
      * @throws Exception
      */
     void reindex(String indexName, List<AtlasElement> elements) throws Exception;
+
+    /**
+     * Starts recovering indices from the specified recovery time and returns TransactionRecovery
+     * @param startTime
+     * @return transactionRecoveryObject
+     */
+    Object startIndexRecovery(long startTime);
+
+    /**
+     * Stop index recovery.
+     * @param txRecoveryObject
+     */
+    void stopIndexRecovery(Object txRecoveryObject);
+
+    /**
+     * Print index recovery stats.
+     * @param txRecoveryObject
+     */
+    void printIndexRecoveryStats(Object txRecoveryObject);
 }
