@@ -18,6 +18,7 @@
 package org.apache.atlas.repository.graphdb.janus;
 
 import com.google.common.base.Function;
+import com.google.common.collect.Iterables;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import org.apache.atlas.ApplicationProperties;
@@ -25,14 +26,19 @@ import org.apache.atlas.AtlasErrorCode;
 import org.apache.atlas.AtlasException;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.groovy.GroovyExpression;
+import org.apache.atlas.model.instance.AtlasEntity;
 import org.apache.atlas.repository.graphdb.AtlasEdge;
 import org.apache.atlas.repository.graphdb.AtlasGraph;
+import org.apache.atlas.repository.graphdb.AtlasGraphIndexClient;
 import org.apache.atlas.repository.graphdb.AtlasGraphManagement;
 import org.apache.atlas.repository.graphdb.AtlasGraphQuery;
 import org.apache.atlas.repository.graphdb.AtlasGraphTraversal;
 import org.apache.atlas.repository.graphdb.AtlasIndexQuery;
+import org.apache.atlas.repository.graphdb.AtlasIndexQueryParameter;
+import org.apache.atlas.repository.graphdb.AtlasPropertyKey;
 import org.apache.atlas.repository.graphdb.AtlasSchemaViolationException;
 import org.apache.atlas.repository.graphdb.AtlasVertex;
+import org.apache.atlas.repository.graphdb.GraphIndexQueryParameters;
 import org.apache.atlas.repository.graphdb.GremlinVersion;
 import org.apache.atlas.repository.graphdb.janus.query.AtlasJanusGraphQuery;
 import org.apache.atlas.repository.graphdb.utils.IteratorToIterableAdapter;
@@ -59,8 +65,11 @@ import org.janusgraph.core.PropertyKey;
 import org.janusgraph.core.SchemaViolationException;
 import org.janusgraph.core.schema.JanusGraphIndex;
 import org.janusgraph.core.schema.JanusGraphManagement;
+import org.janusgraph.core.schema.Parameter;
 import org.janusgraph.diskstorage.BackendException;
 import org.janusgraph.graphdb.database.StandardJanusGraph;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import javax.script.Bindings;
 import javax.script.ScriptEngine;
@@ -73,23 +82,33 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Collectors;
-import java.util.stream.StreamSupport;
 
 import static org.apache.atlas.repository.Constants.INDEX_SEARCH_VERTEX_PREFIX_DEFAULT;
 import static org.apache.atlas.repository.Constants.INDEX_SEARCH_VERTEX_PREFIX_PROPERTY;
 import static org.apache.atlas.repository.graphdb.janus.AtlasJanusGraphDatabase.getGraphInstance;
+import static org.apache.atlas.type.Constants.STATE_PROPERTY_KEY;
 
 /**
  * Janus implementation of AtlasGraph.
  */
 public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusEdge> {
+    private static final Logger LOG = LoggerFactory.getLogger(AtlasJanusGraph.class);
+    private static final Parameter[] EMPTY_PARAMETER_ARRAY  = new Parameter[0];
 
-    private static Configuration APPLICATION_PROPERTIES = null;
+
+    private static       Configuration APPLICATION_PROPERTIES = null;
 
     private final ConvertGremlinValueFunction GREMLIN_VALUE_CONVERSION_FUNCTION = new ConvertGremlinValueFunction();
     private final Set<String>                 multiProperties                   = new HashSet<>();
     private final StandardJanusGraph          janusGraph;
+    private final ThreadLocal<GremlinGroovyScriptEngine> scriptEngine = ThreadLocal.withInitial(() -> {
+        DefaultImportCustomizer.Builder builder = DefaultImportCustomizer.build()
+                                                                         .addClassImports(java.util.function.Function.class)
+                                                                         .addMethodImports(__.class.getMethods())
+                                                                         .addMethodImports(P.class.getMethods());
+        return new GremlinGroovyScriptEngine(builder.create());
+    });
+
 
     public AtlasJanusGraph() {
         this(getGraphInstance());
@@ -115,7 +134,7 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
             }
         }
 
-        janusGraph = (StandardJanusGraph) AtlasJanusGraphDatabase.getGraphInstance();
+        janusGraph = (StandardJanusGraph) graphInstance;
     }
 
     @Override
@@ -154,6 +173,16 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
         return traversal;
     }
 
+    @Override
+    public AtlasEdge getEdgeBetweenVertices(AtlasVertex fromVertex, AtlasVertex toVertex, String edgeLabel) {
+        GraphTraversal gt = V(fromVertex.getId()).outE(edgeLabel).where(__.otherV().hasId(toVertex.getId()));
+
+        Edge gremlinEdge = getFirstActiveEdge(gt);
+        return (gremlinEdge != null)
+                ? GraphDbObjectFactory.createEdge(this, gremlinEdge)
+                : null;
+    }
+
     @Override
     public AtlasEdge<AtlasJanusVertex, AtlasJanusEdge> getEdge(String edgeId) {
         Iterator<Edge> it = getGraph().edges(edgeId);
@@ -197,6 +226,23 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
         return GraphDbObjectFactory.createVertex(this, result);
     }
 
+    @Override
+    public AtlasIndexQueryParameter indexQueryParameter(String parameterName, String parameterValue) {
+        return new AtlasJanusIndexQueryParameter(parameterName, parameterValue);
+    }
+
+    @Override
+    public AtlasGraphIndexClient getGraphIndexClient() throws AtlasException {
+        try {
+            initApplicationProperties();
+
+            return new AtlasJanusGraphIndexClient(APPLICATION_PROPERTIES);
+        } catch (Exception e) {
+            LOG.error("Error encountered in creating Graph Index Client.", e);
+            throw new AtlasException(e);
+        }
+    }
+
     @Override
     public void commit() {
         getGraph().tx().commit();
@@ -208,15 +254,34 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
     }
 
     @Override
-    public AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(String fulltextIndex, String graphQuery) {
-        return indexQuery(fulltextIndex, graphQuery, 0);
+    public AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(String indexName, String graphQuery) {
+        return indexQuery(indexName, graphQuery, 0, null);
     }
 
     @Override
-    public AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(String fulltextIndex, String graphQuery, int offset) {
-        String               prefix = getIndexQueryPrefix();
-        JanusGraphIndexQuery query  = getGraph().indexQuery(fulltextIndex, graphQuery).setElementIdentifier(prefix).offset(offset);
+    public AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(String indexName, String graphQuery, int offset) {
+        return indexQuery(indexName, graphQuery, offset, null);
+    }
 
+    /**
+     * Creates an index query.
+     *
+     * @param indexQueryParameters the parameterObject containing the information needed for creating the index.
+     *
+     */
+    public AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(GraphIndexQueryParameters indexQueryParameters) {
+        return indexQuery(indexQueryParameters.getIndexName(), indexQueryParameters.getGraphQueryString(), indexQueryParameters.getOffset(), indexQueryParameters.getIndexQueryParameters());
+    }
+
+    private AtlasIndexQuery<AtlasJanusVertex, AtlasJanusEdge> indexQuery(String indexName, String graphQuery, int offset, List<AtlasIndexQueryParameter> indexQueryParameterList) {
+        String               prefix = getIndexQueryPrefix();
+        JanusGraphIndexQuery query  = getGraph().indexQuery(indexName, graphQuery).setElementIdentifier(prefix).offset(offset);
+
+        if(indexQueryParameterList != null && indexQueryParameterList.size() > 0) {
+            for(AtlasIndexQueryParameter indexQueryParameter: indexQueryParameterList) {
+                query = query.addParameter(new Parameter(indexQueryParameter.getParameterName(), indexQueryParameter.getParameterValue()));
+            }
+        }
         return new AtlasJanusIndexQuery(this, query);
     }
 
@@ -282,8 +347,8 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
         }
     }
 
-    private JanusGraph getGraph() {
-        return getGraphInstance();
+    public JanusGraph getGraph() {
+        return this.janusGraph;
     }
 
     @Override
@@ -300,20 +365,14 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
 
     @Override
     public GremlinGroovyScriptEngine getGremlinScriptEngine() {
-        DefaultImportCustomizer.Builder importBuilder = DefaultImportCustomizer.build()
-                                                                               .addClassImports(java.util.function.Function.class)
-                                                                               .addMethodImports(__.class.getMethods())
-                                                                               .addMethodImports(P.class.getMethods());
-        GremlinGroovyScriptEngine scriptEngine = new GremlinGroovyScriptEngine(importBuilder.create());
-
-        return scriptEngine;
+        return scriptEngine.get();
     }
 
     @Override
     public void releaseGremlinScriptEngine(ScriptEngine scriptEngine) {
         if (scriptEngine instanceof GremlinGroovyScriptEngine) {
             try {
-                ((GremlinGroovyScriptEngine) scriptEngine).close();
+                ((GremlinGroovyScriptEngine) scriptEngine).reset();
             } catch (Exception e) {
                 // ignore
             }
@@ -372,7 +431,11 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
     }
 
     public Iterable<AtlasVertex<AtlasJanusVertex, AtlasJanusEdge>> wrapVertices(Iterable<? extends Vertex> it) {
-        return StreamSupport.stream(it.spliterator(), false).map(input -> GraphDbObjectFactory.createVertex(AtlasJanusGraph.this, input)).collect(Collectors.toList());
+
+        return Iterables.transform(it,
+                (Function<Vertex, AtlasVertex<AtlasJanusVertex, AtlasJanusEdge>>) input ->
+                    GraphDbObjectFactory.createVertex(AtlasJanusGraph.this, input));
+
     }
 
     public Iterable<AtlasEdge<AtlasJanusVertex, AtlasJanusEdge>> wrapEdges(Iterator<? extends Edge> it) {
@@ -382,7 +445,11 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
     }
 
     public Iterable<AtlasEdge<AtlasJanusVertex, AtlasJanusEdge>> wrapEdges(Iterable<? extends Edge> it) {
-        return StreamSupport.stream(it.spliterator(), false).map(input -> GraphDbObjectFactory.createEdge(AtlasJanusGraph.this, input)).collect(Collectors.toList());
+
+        return Iterables.transform(it,
+                (Function<Edge, AtlasEdge<AtlasJanusVertex, AtlasJanusEdge>>) input ->
+                        GraphDbObjectFactory.createEdge(AtlasJanusGraph.this, input));
+
     }
 
     public void addMultiProperties(Set<String> names) {
@@ -390,6 +457,15 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
     }
 
 
+    String getIndexFieldName(AtlasPropertyKey propertyKey, JanusGraphIndex graphIndex, Parameter ... parameters) {
+        PropertyKey janusKey = AtlasJanusObjectFactory.createPropertyKey(propertyKey);
+        if(parameters == null) {
+            parameters = EMPTY_PARAMETER_ARRAY;
+        }
+        return janusGraph.getIndexSerializer().getDefaultFieldName(janusKey, parameters, graphIndex.getBackingIndex());
+    }
+
+
     private String getIndexQueryPrefix() {
         final String ret;
 
@@ -492,9 +568,22 @@ public class AtlasJanusGraph implements AtlasGraph<AtlasJanusVertex, AtlasJanusE
 
 
     private final class ConvertGremlinValueFunction implements Function<Object, Object> {
+
         @Override
         public Object apply(Object input) {
             return convertGremlinValue(input);
         }
     }
+    private Edge getFirstActiveEdge(GraphTraversal gt) {
+        while (gt.hasNext()) {
+            Edge gremlinEdge = (Edge) gt.next();
+            if (gremlinEdge != null && gremlinEdge.property(STATE_PROPERTY_KEY).isPresent() &&
+                    gremlinEdge.property(STATE_PROPERTY_KEY).value().equals(AtlasEntity.Status.ACTIVE.toString())
+            ) {
+                return gremlinEdge;
+            }
+        }
+
+        return null;
+    }
 }
