@@ -28,8 +28,8 @@ import org.apache.atlas.repository.graphdb.janus.serializer.BigDecimalSerializer
 import org.apache.atlas.repository.graphdb.janus.serializer.BigIntegerSerializer;
 import org.apache.atlas.repository.graphdb.janus.serializer.TypeCategorySerializer;
 import org.apache.atlas.typesystem.types.DataTypes.TypeCategory;
-import org.apache.atlas.utils.AtlasPerfTracer;
 import org.apache.commons.configuration.Configuration;
+import org.apache.commons.configuration.ConfigurationConverter;
 import org.apache.tinkerpop.gremlin.structure.io.graphson.GraphSONMapper;
 import org.janusgraph.core.JanusGraph;
 import org.janusgraph.core.JanusGraphException;
@@ -37,6 +37,7 @@ import org.janusgraph.core.JanusGraphFactory;
 import org.janusgraph.core.schema.JanusGraphManagement;
 import org.janusgraph.diskstorage.StandardIndexProvider;
 import org.janusgraph.diskstorage.StandardStoreManager;
+import org.janusgraph.diskstorage.es.ElasticSearch7Index;
 import org.janusgraph.diskstorage.solr.Solr6Index;
 import org.janusgraph.graphdb.database.serialize.attribute.SerializableSerializer;
 import org.janusgraph.graphdb.tinkerpop.JanusGraphIoRegistry;
@@ -48,28 +49,37 @@ import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.math.BigDecimal;
 import java.math.BigInteger;
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Properties;
+
+import static org.apache.atlas.ApplicationProperties.DEFAULT_INDEX_RECOVERY;
+import static org.apache.atlas.ApplicationProperties.INDEX_RECOVERY_CONF;
 
 /**
  * Default implementation for Graph Provider that doles out JanusGraph.
  */
 public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex, AtlasJanusEdge> {
     private static final Logger LOG      = LoggerFactory.getLogger(AtlasJanusGraphDatabase.class);
-    private static final Logger PERF_LOG = AtlasPerfTracer.getPerfLogger("AtlasJanusGraphDatabase");
 
     private static final String OLDER_STORAGE_EXCEPTION = "Storage version is incompatible with current client";
 
     /**
      * Constant for the configuration property that indicates the prefix.
      */
-    public static final String GRAPH_PREFIX         = "atlas.graph";
-    public static final String INDEX_BACKEND_CONF   = "index.search.backend";
-    public static final String SOLR_ZOOKEEPER_URL   = "atlas.graph.index.search.solr.zookeeper-url";
-    public static final String SOLR_ZOOKEEPER_URLS  = "atlas.graph.index.search.solr.zookeeper-urls";
-    public static final String INDEX_BACKEND_LUCENE = "lucene";
-    public static final String INDEX_BACKEND_ES     = "elasticsearch";
+    public static final String GRAPH_PREFIX               = "atlas.graph";
+    public static final String INDEX_BACKEND_CONF         = "index.search.backend";
+    public static final String SOLR_ZOOKEEPER_URL         = "atlas.graph.index.search.solr.zookeeper-url";
+    public static final String SOLR_ZOOKEEPER_URLS        = "atlas.graph.index.search.solr.zookeeper-urls";
+    public static final String INDEX_BACKEND_LUCENE       = "lucene";
+    public static final String INDEX_BACKEND_ES           = "elasticsearch";
+    public static final String GRAPH_TX_LOG_CONF          = "tx.log-tx";
+    public static final String GRAPH_TX_LOG_VERBOSE_CONF  = "tx.recovery.verbose";
+    public static final String SOLR_INDEX_TX_LOG_TTL_CONF = "write.ahead.log.ttl.in.hours";
+    public static final String GRAPH_TX_LOG_TTL_CONF      = "log.tx.ttl";
+    public static final long   DEFAULT_GRAPH_TX_LOG_TTL   = 72; //Hrs
 
     private static volatile AtlasJanusGraph atlasGraphInstance = null;
     private static volatile JanusGraph graphInstance;
@@ -93,18 +103,18 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
         Configuration janusConfig = ApplicationProperties.getSubsetConfiguration(configProperties, GRAPH_PREFIX);
 
         //add serializers for non-standard property value types that Atlas uses
-        janusConfig.addProperty("attributes.custom.attribute1.attribute-class", TypeCategory.class.getName());
-        janusConfig.addProperty("attributes.custom.attribute1.serializer-class", TypeCategorySerializer.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute1.attribute-class", TypeCategory.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute1.serializer-class", TypeCategorySerializer.class.getName());
 
         //not ideal, but avoids making large changes to Atlas
-        janusConfig.addProperty("attributes.custom.attribute2.attribute-class", ArrayList.class.getName());
-        janusConfig.addProperty("attributes.custom.attribute2.serializer-class", SerializableSerializer.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute2.attribute-class", ArrayList.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute2.serializer-class", SerializableSerializer.class.getName());
 
-        janusConfig.addProperty("attributes.custom.attribute3.attribute-class", BigInteger.class.getName());
-        janusConfig.addProperty("attributes.custom.attribute3.serializer-class", BigIntegerSerializer.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute3.attribute-class", BigInteger.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute3.serializer-class", BigIntegerSerializer.class.getName());
 
-        janusConfig.addProperty("attributes.custom.attribute4.attribute-class", BigDecimal.class.getName());
-        janusConfig.addProperty("attributes.custom.attribute4.serializer-class", BigDecimalSerializer.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute4.attribute-class", BigDecimal.class.getName());
+        janusConfig.setProperty("attributes.custom.attribute4.serializer-class", BigDecimalSerializer.class.getName());
 
         return janusConfig;
     }
@@ -113,6 +123,8 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
         addHBase2Support();
 
         addSolr6Index();
+
+        addElasticSearch7Index();
     }
 
     private static void addHBase2Support() {
@@ -155,6 +167,27 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
         }
     }
 
+    private static void addElasticSearch7Index() {
+        try {
+            Field field = StandardIndexProvider.class.getDeclaredField("ALL_MANAGER_CLASSES");
+            field.setAccessible(true);
+
+            Field modifiersField = Field.class.getDeclaredField("modifiers");
+            modifiersField.setAccessible(true);
+            modifiersField.setInt(field, field.getModifiers() & ~Modifier.FINAL);
+
+            Map<String, String> customMap = new HashMap<>(StandardIndexProvider.getAllProviderClasses());
+            customMap.put("elasticsearch", ElasticSearch7Index.class.getName());
+            ImmutableMap<String, String> immap = ImmutableMap.copyOf(customMap);
+            field.set(null, immap);
+
+            LOG.debug("Injected es7 index - {}", ElasticSearch7Index.class.getName());
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        }
+    }
+
+
     public static JanusGraph getGraphInstance() {
         if (graphInstance == null) {
             synchronized (AtlasJanusGraphDatabase.class) {
@@ -166,8 +199,11 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
                         throw new RuntimeException(e);
                     }
 
-                    graphInstance = initJanusGraph(config);
+                    configureTxLogBasedIndexRecovery();
+
+                    graphInstance      = initJanusGraph(config);
                     atlasGraphInstance = new AtlasJanusGraph();
+
                     validateIndexBackend(config);
 
                 }
@@ -178,25 +214,75 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
 
     @VisibleForTesting
     static JanusGraph initJanusGraph(Configuration config) {
+
+        org.apache.commons.configuration2.Configuration conf2 = createConfiguration2(config);
         try {
-            return JanusGraphFactory.open(config);
+            return JanusGraphFactory.open(conf2);
         } catch (JanusGraphException e) {
             LOG.warn("JanusGraphException: {}", e.getMessage());
             if (e.getMessage().startsWith(OLDER_STORAGE_EXCEPTION)) {
                 LOG.info("Newer client is being used with older janus storage version. Setting allow-upgrade=true and reattempting connection");
                 config.addProperty("graph.allow-upgrade", true);
-                return JanusGraphFactory.open(config);
+                return JanusGraphFactory.open(conf2);
             } else {
                 throw new RuntimeException(e);
             }
         }
     }
 
+    public static void configureTxLogBasedIndexRecovery() {
+        try {
+            boolean  recoveryEnabled = ApplicationProperties.get().getBoolean(INDEX_RECOVERY_CONF, DEFAULT_INDEX_RECOVERY);
+            long     ttl             = ApplicationProperties.get().getLong(SOLR_INDEX_TX_LOG_TTL_CONF, DEFAULT_GRAPH_TX_LOG_TTL);
+            Duration txLogTtlSecs    = Duration.ofSeconds(Duration.ofHours(ttl).getSeconds());
+
+            Map<String, Object> properties = new HashMap<String, Object>() {{
+                put(GRAPH_TX_LOG_CONF, recoveryEnabled);
+                put(GRAPH_TX_LOG_VERBOSE_CONF, recoveryEnabled);
+                put(GRAPH_TX_LOG_TTL_CONF, txLogTtlSecs);
+            }};
+
+            updateGlobalConfiguration(properties);
+
+            LOG.info("Tx Log-based Index Recovery: {}!", recoveryEnabled ? "Enabled" : "Disabled");
+        } catch (Exception e) {
+            LOG.error("Error: Failed!", e);
+        }
+    }
+
+    private static void updateGlobalConfiguration(Map<String, Object> map) {
+        JanusGraph           graph            = null;
+        JanusGraphManagement managementSystem = null;
+
+        try {
+            graph            = initJanusGraph(getConfiguration());
+            managementSystem = graph.openManagement();
+
+            for (Map.Entry<String, Object> entry : map.entrySet()) {
+                managementSystem.set(entry.getKey(), entry.getValue());
+            }
+
+            LOG.info("Global properties updated!: {}", map);
+        } catch (Exception ex) {
+            LOG.error("Error updating global configuration: {}", map, ex);
+        } finally {
+            if (managementSystem != null) {
+                managementSystem.commit();
+            }
+
+            if (graph != null) {
+                graph.close();
+            }
+        }
+    }
+
     public static JanusGraph getBulkLoadingGraphInstance() {
         try {
             Configuration cfg = getConfiguration();
             cfg.setProperty("storage.batch-loading", true);
-            return JanusGraphFactory.open(cfg);
+
+            org.apache.commons.configuration2.Configuration conf2 = createConfiguration2(cfg);
+            return JanusGraphFactory.open(conf2);
         } catch (IllegalArgumentException ex) {
             LOG.error("getBulkLoadingGraphInstance: Failed!", ex);
         } catch (AtlasException ex) {
@@ -206,6 +292,12 @@ public class AtlasJanusGraphDatabase implements GraphDatabase<AtlasJanusVertex,
         return null;
     }
 
+    private static org.apache.commons.configuration2.Configuration createConfiguration2(Configuration conf) {
+        Properties properties = ConfigurationConverter.getProperties(conf);
+
+        return org.apache.commons.configuration2.ConfigurationConverter.getConfiguration(properties);
+    }
+
     public static void unload() {
         synchronized (AtlasJanusGraphDatabase.class) {
 
