@@ -19,42 +19,59 @@ package org.apache.atlas.repository.graphdb.janus;
 
 import com.google.common.base.Preconditions;
 import org.apache.atlas.AtlasConfiguration;
-import org.apache.atlas.exception.AtlasBaseException;
-import org.apache.atlas.repository.graphdb.AtlasEdgeDirection;
-import org.apache.atlas.repository.graphdb.AtlasElement;
-import org.apache.tinkerpop.gremlin.structure.Direction;
-import org.apache.tinkerpop.gremlin.structure.Element;
-import org.janusgraph.core.Cardinality;
-import org.janusgraph.core.EdgeLabel;
-import org.janusgraph.core.JanusGraphElement;
-import org.janusgraph.core.PropertyKey;
-import org.janusgraph.core.schema.*;
-import org.janusgraph.core.schema.JanusGraphManagement.IndexBuilder;
-import org.janusgraph.diskstorage.BackendTransaction;
-import org.janusgraph.diskstorage.indexing.IndexEntry;
-import org.janusgraph.graphdb.database.IndexSerializer;
-import org.janusgraph.graphdb.database.StandardJanusGraph;
-import org.janusgraph.graphdb.database.management.ManagementSystem;
-import org.janusgraph.graphdb.internal.Token;
 import org.apache.atlas.repository.graphdb.AtlasCardinality;
+import org.apache.atlas.repository.graphdb.AtlasEdgeDirection;
 import org.apache.atlas.repository.graphdb.AtlasEdgeLabel;
+import org.apache.atlas.repository.graphdb.AtlasElement;
 import org.apache.atlas.repository.graphdb.AtlasGraphIndex;
 import org.apache.atlas.repository.graphdb.AtlasGraphManagement;
 import org.apache.atlas.repository.graphdb.AtlasPropertyKey;
 import org.apache.commons.lang.StringUtils;
+import org.apache.tinkerpop.gremlin.structure.Direction;
 import org.apache.tinkerpop.gremlin.structure.Edge;
+import org.apache.tinkerpop.gremlin.structure.Element;
 import org.apache.tinkerpop.gremlin.structure.Vertex;
+import org.janusgraph.core.Cardinality;
+import org.janusgraph.core.EdgeLabel;
+import org.janusgraph.core.JanusGraph;
+import org.janusgraph.core.JanusGraphElement;
+import org.janusgraph.core.JanusGraphFactory;
+import org.janusgraph.core.PropertyKey;
+import org.janusgraph.core.log.TransactionRecovery;
+import org.janusgraph.core.schema.ConsistencyModifier;
+import org.janusgraph.core.schema.JanusGraphIndex;
+import org.janusgraph.core.schema.JanusGraphManagement;
+import org.janusgraph.core.schema.JanusGraphManagement.IndexBuilder;
+import org.janusgraph.core.schema.Mapping;
+import org.janusgraph.core.schema.Parameter;
+import org.janusgraph.core.schema.PropertyKeyMaker;
+import org.janusgraph.core.schema.SchemaStatus;
+import org.janusgraph.diskstorage.BackendTransaction;
+import org.janusgraph.diskstorage.indexing.IndexEntry;
+import org.janusgraph.graphdb.database.IndexSerializer;
+import org.janusgraph.graphdb.database.StandardJanusGraph;
+import org.janusgraph.graphdb.database.management.GraphIndexStatusReport;
+import org.janusgraph.graphdb.database.management.ManagementSystem;
+import org.janusgraph.graphdb.internal.Token;
+import org.janusgraph.graphdb.log.StandardTransactionLogProcessor;
 import org.janusgraph.graphdb.transaction.StandardJanusGraphTx;
 import org.janusgraph.graphdb.types.IndexType;
 import org.janusgraph.graphdb.types.MixedIndexType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.time.Instant;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ExecutionException;
+
+import static org.janusgraph.core.schema.SchemaAction.ENABLE_INDEX;
+import static org.janusgraph.core.schema.SchemaStatus.ENABLED;
+import static org.janusgraph.core.schema.SchemaStatus.INSTALLED;
+import static org.janusgraph.core.schema.SchemaStatus.REGISTERED;
 
 /**
  * Janus implementation of AtlasGraphManagement.
@@ -298,6 +315,57 @@ public class AtlasJanusGraphManagement implements AtlasGraphManagement {
         }
     }
 
+    @Override
+    public void updateSchemaStatus() {
+        updateSchemaStatus(this.management, this.graph.getGraph(), Vertex.class);
+        updateSchemaStatus(this.management, this.graph.getGraph(), Edge.class);
+    }
+
+    public static void updateSchemaStatus(JanusGraphManagement mgmt, JanusGraph graph, Class<? extends Element> elementType) {
+        LOG.info("updating SchemaStatus for {}: Starting...", elementType.getSimpleName());
+        int count = 0;
+
+        Iterable<JanusGraphIndex> iterable = mgmt.getGraphIndexes(elementType);
+
+        for (JanusGraphIndex index : iterable) {
+
+            if (index.isCompositeIndex()) {
+                PropertyKey[] propertyKeys = index.getFieldKeys();
+                SchemaStatus status       = index.getIndexStatus(propertyKeys[0]);
+                String        indexName    = index.name();
+
+                try {
+                    if (status == REGISTERED) {
+                        JanusGraphManagement management = graph.openManagement();
+                        JanusGraphIndex indexToUpdate   = management.getGraphIndex(indexName);
+                        management.updateIndex(indexToUpdate, ENABLE_INDEX).get();
+                        management.commit();
+
+                        GraphIndexStatusReport report = ManagementSystem.awaitGraphIndexStatus(graph, indexName).status(ENABLED).call();
+
+                        if (!report.getConvergedKeys().isEmpty() && report.getConvergedKeys().containsKey(indexName)) {
+                            LOG.info("SchemaStatus updated for index: {}, from {} to {}.", index.name(), REGISTERED, ENABLED);
+
+                            count++;
+                        } else if (!report.getNotConvergedKeys().isEmpty() && report.getNotConvergedKeys().containsKey(indexName)) {
+                            LOG.error("SchemaStatus failed to update index: {}, from {} to {}.", index.name(), REGISTERED, ENABLED);
+                        }
+
+                    } else if (status == INSTALLED) {
+                        LOG.warn("SchemaStatus {} found for index: {}", INSTALLED, indexName);
+
+                    }
+                } catch (InterruptedException e) {
+                    LOG.error("IllegalStateException for indexName : {}, Exception: ", indexName, e);
+                } catch (ExecutionException e) {
+                    LOG.error("ExecutionException for indexName : {}, Exception: ", indexName, e);
+                }
+            }
+        }
+
+        LOG.info("updating SchemaStatus for {}: {}: Done!", elementType.getSimpleName(), count);
+    }
+
     private static void setConsistency(JanusGraphManagement mgmt, Class<? extends Element> elementType) {
         LOG.info("setConsistency: {}: Starting...", elementType.getSimpleName());
         int count = 0;
@@ -347,6 +415,62 @@ public class AtlasJanusGraphManagement implements AtlasGraphManagement {
         }
     }
 
+    @Override
+    public Object startIndexRecovery(long recoveryStartTime) {
+        Instant    recoveryStartInstant = Instant.ofEpochMilli(recoveryStartTime);
+        JanusGraph janusGraph           = this.graph.getGraph();
+
+        return JanusGraphFactory.startTransactionRecovery(janusGraph, recoveryStartInstant);
+    }
+
+    @Override
+    public void stopIndexRecovery(Object txRecoveryObject) {
+        if (txRecoveryObject == null) {
+            return;
+        }
+
+        try {
+            if (txRecoveryObject instanceof TransactionRecovery) {
+                TransactionRecovery txRecovery = (TransactionRecovery) txRecoveryObject;
+                StandardJanusGraph  janusGraph = (StandardJanusGraph) this.graph.getGraph();
+
+                LOG.info("stopIndexRecovery: Index Client is unhealthy. Index recovery: Paused!");
+
+                janusGraph.getBackend().getSystemTxLog().close();
+
+                txRecovery.shutdown();
+            } else {
+                LOG.error("stopIndexRecovery({}): Invalid transaction recovery object!", txRecoveryObject);
+            }
+        } catch (Exception e) {
+            LOG.warn("stopIndexRecovery: Error while shutting down transaction recovery", e);
+        }
+    }
+
+    @Override
+    public void printIndexRecoveryStats(Object txRecoveryObject) {
+        if (txRecoveryObject == null) {
+            return;
+        }
+
+        try {
+            if (txRecoveryObject instanceof TransactionRecovery) {
+                StandardTransactionLogProcessor txRecovery = (StandardTransactionLogProcessor) txRecoveryObject;
+                long[]                          statistics = txRecovery.getStatistics();
+
+                if (statistics.length >= 2) {
+                    LOG.info("Index Recovery: Stats: Success:{}: Failed: {}", statistics[0], statistics[1]);
+                } else {
+                    LOG.info("Index Recovery: Stats: {}", statistics);
+                }
+            } else {
+                LOG.error("Transaction stats: Invalid transaction recovery object!: Unexpected type: {}: Details: {}", txRecoveryObject.getClass().toString(), txRecoveryObject);
+            }
+        } catch (Exception e) {
+            LOG.error("Error: Retrieving log transaction stats!", e);
+        }
+    }
+
     private void reindexElement(ManagementSystem managementSystem, IndexSerializer indexSerializer, MixedIndexType indexType, List<AtlasElement> elements) throws Exception {
         Map<String, Map<String, List<IndexEntry>>> documentsPerStore = new HashMap<>();
         StandardJanusGraphTx tx = managementSystem.getWrappedTx();
