@@ -71,6 +71,9 @@ public enum AtlasConfiguration {
     IMPORT_TEMP_DIRECTORY("atlas.import.temp.directory", ""),
     MIGRATION_IMPORT_START_POSITION("atlas.migration.import.start.position", 0),
     LINEAGE_USING_GREMLIN("atlas.lineage.query.use.gremlin", false),
+    LINEAGE_ON_DEMAND_ENABLED("atlas.lineage.on.demand.enabled", false),
+    LINEAGE_ON_DEMAND_DEFAULT_NODE_COUNT("atlas.lineage.on.demand.default.node.count", 3),
+    LINEAGE_MAX_NODE_COUNT("atlas.lineage.max.node.count", 9000),
 
     HTTP_HEADER_SERVER_VALUE("atlas.http.header.server.value","Apache Atlas"),
     STORAGE_CONSISTENCY_LOCK_ENABLED("atlas.graph.storage.consistency-lock.enabled", true),
@@ -80,7 +83,10 @@ public enum AtlasConfiguration {
     DSL_EXECUTOR_TRAVERSAL("atlas.dsl.executor.traversal", true),
     DSL_CACHED_TRANSLATOR("atlas.dsl.cached.translator", true),
     DEBUG_METRICS_ENABLED("atlas.debug.metrics.enabled", false),
-    TASKS_USE_ENABLED("atlas.tasks.enabled", true);
+    TASKS_USE_ENABLED("atlas.tasks.enabled", true),
+    SESSION_TIMEOUT_SECS("atlas.session.timeout.secs", -1),
+    UPDATE_COMPOSITE_INDEX_STATUS("atlas.update.composite.index.status", true),
+    METRICS_TIME_TO_LIVE_HOURS( "atlas.metrics.ttl.hours", 336); // 14 days default
 
     private static final Configuration APPLICATION_PROPERTIES;
 
