@@ -23,6 +23,7 @@ import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 
 import org.apache.atlas.model.typedef.AtlasBaseTypeDef;
+import org.apache.commons.collections.CollectionUtils;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
@@ -32,6 +33,7 @@ import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
 import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;
 
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 
 @JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@@ -40,8 +42,10 @@ import java.util.Objects;
 @XmlRootElement
 @XmlAccessorType(XmlAccessType.PROPERTY)
 public class ClassificationAssociateRequest {
-    private AtlasClassification classification;
-    private List<String>        entityGuids;
+    private AtlasClassification         classification;
+    private List<String>                entityGuids;
+    private List<Map<String, Object>>   entitiesUniqueAttributes;
+    private String                      entityTypeName;
 
     public ClassificationAssociateRequest() {
         this(null, null);
@@ -52,6 +56,35 @@ public class ClassificationAssociateRequest {
         setClassification(classification);
     }
 
+    public ClassificationAssociateRequest(String entityTypeName, List<Map<String, Object>> entitiesUniqueAttributes, AtlasClassification classification) {
+        setEntitiesUniqueAttributes(entitiesUniqueAttributes);
+        setClassification(classification);
+        setEntityTypeName(entityTypeName);
+    }
+
+    public ClassificationAssociateRequest(List<String> entityGuids, String entityTypeName, List<Map<String, Object>> entitiesUniqueAttributes, AtlasClassification classification) {
+        setEntityGuids(entityGuids);
+        setEntitiesUniqueAttributes(entitiesUniqueAttributes);
+        setClassification(classification);
+        setEntityTypeName(entityTypeName);
+    }
+
+    public String getEntityTypeName() {
+        return entityTypeName;
+    }
+
+    public void setEntityTypeName(String entityTypeName) {
+        this.entityTypeName = entityTypeName;
+    }
+
+    public List<Map<String, Object>> getEntitiesUniqueAttributes() {
+        return entitiesUniqueAttributes;
+    }
+
+    public void setEntitiesUniqueAttributes(List<Map<String, Object>> entitiesUniqueAttributes) {
+        this.entitiesUniqueAttributes = entitiesUniqueAttributes;
+    }
+
     public AtlasClassification getClassification() { return classification; }
 
     public void setClassification(AtlasClassification classification) { this.classification = classification; }
@@ -68,12 +101,12 @@ public class ClassificationAssociateRequest {
 
         ClassificationAssociateRequest that = (ClassificationAssociateRequest) o;
 
-        return Objects.equals(classification, that.classification) && Objects.equals(entityGuids, that.entityGuids);
+        return Objects.equals(classification, that.classification) && Objects.equals(entityGuids, that.entityGuids) && CollectionUtils.isEqualCollection(entitiesUniqueAttributes, that.entitiesUniqueAttributes);
     }
 
     @Override
     public int hashCode() {
-        return Objects.hash(classification, entityGuids);
+        return Objects.hash(classification, entityGuids, entitiesUniqueAttributes);
     }
 
     public StringBuilder toString(StringBuilder sb) {
@@ -86,9 +119,17 @@ public class ClassificationAssociateRequest {
         if (classification != null) {
             classification.toString(sb);
         }
-        sb.append(", entityGuids=[");
+        sb.append("', entityGuids=[");
         AtlasBaseTypeDef.dumpObjects(entityGuids, sb);
         sb.append("]");
+        sb.append(", entityTypeName=[");
+        if (entityTypeName != null) {
+            sb.append(entityTypeName);
+        }
+        sb.append("]");
+        sb.append(", entitiesUniqueAttributes=[");
+        AtlasBaseTypeDef.dumpObjects(entitiesUniqueAttributes, sb);
+        sb.append("]");
         sb.append('}');
 
         return sb;
@@ -98,5 +139,4 @@ public class ClassificationAssociateRequest {
     public String toString() {
         return toString(new StringBuilder()).toString();
     }
-
 }
