@@ -444,9 +444,7 @@ public class AtlasArrayType extends AtlasType {
     }
 
     private boolean isEmptyArrayValue(Object val) {
-        if (val == null) {
-            return true;
-        } else if (val instanceof Collection) {
+        if (val instanceof Collection) {
             return ((Collection) val).isEmpty();
         } else if (val.getClass().isArray()) {
             return Array.getLength(val) == 0;
