@@ -19,16 +19,14 @@
 package org.apache.atlas.hook;
 
 
-import org.apache.log4j.Appender;
+import org.apache.atlas.notification.LogConfigUtils;
 import org.apache.log4j.DailyRollingFileAppender;
-import org.apache.log4j.FileAppender;
 import org.apache.log4j.Level;
 import org.apache.log4j.Logger;
 import org.apache.log4j.PatternLayout;
 
 import java.io.File;
 import java.io.IOException;
-import java.util.Enumeration;
 
 /**
  * A logger wrapper that can be used to write messages that failed to be sent to a log file.
@@ -46,7 +44,7 @@ public class FailedMessagesLogger {
     }
 
     void init() {
-        String rootLoggerDirectory = getRootLoggerDirectory();
+        String rootLoggerDirectory = LogConfigUtils.getRootDir();
         if (rootLoggerDirectory == null) {
             return;
         }
@@ -62,38 +60,7 @@ public class FailedMessagesLogger {
         }
     }
 
-    /**
-     * Get the root logger file location under which the failed log messages will be written.
-     *
-     * Since this class is used in Hooks which run within JVMs of other components like Hive,
-     * we want to write the failed messages file under the same location as where logs from
-     * the host component are saved. This method attempts to get such a location from the
-     * root logger's appenders. It will work only if at least one of the appenders is a {@link FileAppender}
-     *
-     * @return directory under which host component's logs are stored.
-     */
-    private String getRootLoggerDirectory() {
-        String      rootLoggerDirectory = null;
-        Logger      rootLogger          = Logger.getRootLogger();
-        Enumeration allAppenders        = rootLogger.getAllAppenders();
-
-        if (allAppenders != null) {
-            while (allAppenders.hasMoreElements()) {
-                Appender appender = (Appender) allAppenders.nextElement();
-
-                if (appender instanceof FileAppender) {
-                    FileAppender fileAppender   = (FileAppender) appender;
-                    String       rootLoggerFile = fileAppender.getFile();
-
-                    rootLoggerDirectory = rootLoggerFile != null ? new File(rootLoggerFile).getParent() : null;
-                    break;
-                }
-            }
-        }
-        return rootLoggerDirectory;
-    }
-
-    void log(String message) {
+    public void log(String message) {
         logger.error(message);
     }
 }
