@@ -34,10 +34,12 @@ import org.apache.atlas.model.discovery.AtlasSearchResult.AtlasFullTextResult;
 import org.apache.atlas.model.discovery.AtlasSearchResult.AtlasQueryType;
 import org.apache.atlas.model.discovery.AtlasSuggestionsResult;
 import org.apache.atlas.model.discovery.QuickSearchParameters;
+import org.apache.atlas.model.discovery.RelationshipSearchParameters;
 import org.apache.atlas.model.discovery.SearchParameters;
 import org.apache.atlas.model.instance.AtlasEntity;
 import org.apache.atlas.model.instance.AtlasEntityHeader;
 import org.apache.atlas.model.instance.AtlasObjectId;
+import org.apache.atlas.model.instance.AtlasRelationshipHeader;
 import org.apache.atlas.model.profile.AtlasUserSavedSearch;
 import org.apache.atlas.query.QueryParams;
 import org.apache.atlas.query.executors.DSLQueryExecutor;
@@ -449,6 +451,46 @@ public class EntityDiscoveryService implements AtlasDiscoveryService {
         return searchWithSearchContext(new SearchContext(searchParameters, typeRegistry, graph, indexer.getVertexIndexKeys()));
     }
 
+    @Override
+    @GraphTransaction
+    public AtlasSearchResult searchRelationsWithParameters(RelationshipSearchParameters searchParameters) throws AtlasBaseException {
+        SearchContext searchContext = new SearchContext(createSearchParameters(searchParameters),
+                typeRegistry,
+                graph,
+                null);
+        return searchRelationsWithSearchContext(searchContext);
+    }
+
+    private AtlasSearchResult searchRelationsWithSearchContext(SearchContext searchContext) throws AtlasBaseException {
+        SearchParameters  searchParameters = searchContext.getSearchParameters();
+        AtlasSearchResult ret              = new AtlasSearchResult(searchParameters);
+        final QueryParams params           = QueryParams.getNormalizedParams(searchParameters.getLimit(),searchParameters.getOffset());
+
+        searchParameters.setLimit(params.limit());
+        searchParameters.setOffset(params.offset());
+
+        if (!searchContext.needRelationshipProcessor()) {
+            return ret;
+        }
+
+        RelationshipSearchProcessor rsp = new RelationshipSearchProcessor(searchContext, indexer.getEdgeIndexKeys());
+        List<AtlasEdge> edges           = rsp.executeEdges();
+
+        ret.setApproximateCount(rsp.getResultCount());
+
+        String nextMarker = rsp.getNextMarker();
+        if (StringUtils.isNotEmpty(nextMarker)) {
+            ret.setNextMarker(nextMarker);
+        }
+
+        for (AtlasEdge edge : edges) {
+            AtlasRelationshipHeader relation = entityRetriever.mapEdgeToAtlasRelationshipHeader(edge);
+            ret.addRelation(relation);
+        }
+
+        return ret;
+    }
+
     private AtlasSearchResult searchWithSearchContext(SearchContext searchContext) throws AtlasBaseException {
         SearchParameters  searchParameters = searchContext.getSearchParameters();
         AtlasSearchResult ret              = new AtlasSearchResult(searchParameters);
@@ -468,6 +510,32 @@ public class EntityDiscoveryService implements AtlasDiscoveryService {
                 ret.setNextMarker(nextMarker);
             }
 
+            //If excludeHeaderAttributes is true, only primitive attributes requested in 'attributes' field will be sent in the response
+            Set<String> attributes = searchParameters.getAttributes();
+            if (searchContext.excludeHeaderAttributes()) {
+
+                AtlasSearchResult.AttributeSearchResult attributeSearchResult = new AtlasSearchResult.AttributeSearchResult();
+                attributeSearchResult.setName(new ArrayList<>(attributes));
+
+                Collection<List<Object>> values = new ArrayList<>();
+                for (AtlasVertex vertex : resultList) {
+                    List<Object> row = new ArrayList<>();
+
+                    for (String attrName : attributes) {
+                        AtlasEntityType entityType = searchContext.getEntityTypes().iterator().next();
+                        AtlasAttribute  attribute  = entityType.getAttribute(attrName);
+                        Object value               = vertex.getProperty(attribute.getVertexPropertyName(), Object.class);
+
+                        row.add(value != null ? value : StringUtils.EMPTY);
+                    }
+                    values.add(row);
+                }
+                attributeSearchResult.setValues(new ArrayList<>(values));
+
+                ret.setAttributes(attributeSearchResult);
+                return ret;
+            }
+
             // By default any attribute that shows up in the search parameter should be sent back in the response
             // If additional values are requested then the entityAttributes will be a superset of the all search attributes
             // and the explicitly requested attribute(s)
@@ -920,6 +988,24 @@ public class EntityDiscoveryService implements AtlasDiscoveryService {
         searchParameters.setOffset(quickSearchParameters.getOffset());
         searchParameters.setEntityFilters(quickSearchParameters.getEntityFilters());
         searchParameters.setAttributes(quickSearchParameters.getAttributes());
+        searchParameters.setSortBy(quickSearchParameters.getSortBy());
+        searchParameters.setSortOrder(quickSearchParameters.getSortOrder());
+        searchParameters.setExcludeHeaderAttributes(quickSearchParameters.getExcludeHeaderAttributes());
+
+        return searchParameters;
+    }
+
+    public static SearchParameters createSearchParameters(RelationshipSearchParameters relationshipSearchParameters) {
+        SearchParameters searchParameters = new SearchParameters();
+
+        searchParameters.setRelationshipName(relationshipSearchParameters.getRelationshipName());
+        searchParameters.setIncludeSubTypes(relationshipSearchParameters.isIncludeSubTypes());
+        searchParameters.setLimit(relationshipSearchParameters.getLimit());
+        searchParameters.setOffset(relationshipSearchParameters.getOffset());
+        searchParameters.setRelationshipFilters(relationshipSearchParameters.getRelationshipFilters());
+        searchParameters.setSortBy(relationshipSearchParameters.getSortBy());
+        searchParameters.setSortOrder(relationshipSearchParameters.getSortOrder());
+        searchParameters.setMarker(relationshipSearchParameters.getMarker());
 
         return searchParameters;
     }
