@@ -23,6 +23,7 @@ import org.apache.atlas.repository.Constants;
 import org.apache.atlas.repository.graphdb.AtlasIndexQuery;
 import org.apache.atlas.repository.graphdb.AtlasVertex;
 import org.apache.atlas.repository.store.graph.v2.AtlasGraphUtilsV2;
+import org.apache.atlas.type.AtlasEntityType;
 import org.apache.atlas.utils.AtlasPerfTracer;
 import org.apache.commons.collections.CollectionUtils;
 import org.slf4j.Logger;
@@ -139,6 +140,13 @@ public class FullTextSearchProcessor extends SearchProcessor {
 
                         continue;
                     }
+                    //skip internalTypes
+                    String entityTypeName = AtlasGraphUtilsV2.getTypeName(vertex);
+                    AtlasEntityType entityType = context.getTypeRegistry().getEntityTypeByName(entityTypeName);
+                    if (entityType  != null && entityType.isInternalType()) {
+                        continue;
+                    }
+
 
                     if (activeOnly && AtlasGraphUtilsV2.getState(vertex) != AtlasEntity.Status.ACTIVE) {
                         continue;
