@@ -25,14 +25,21 @@ import org.apache.atlas.type.AtlasStructType.AtlasAttribute.AtlasRelationshipEdg
 import org.apache.atlas.type.AtlasType;
 import org.apache.commons.lang.StringUtils;
 
+import java.util.Arrays;
+import java.util.HashSet;
+import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import static org.apache.atlas.repository.Constants.CLASSIFICATION_LABEL;
+
 public class IdentifierHelper {
 
     private static final Pattern SINGLE_QUOTED_IDENTIFIER   = Pattern.compile("'(\\w[\\w\\d\\.\\s]*)'");
     private static final Pattern DOUBLE_QUOTED_IDENTIFIER   = Pattern.compile("\"(\\w[\\w\\d\\.\\s]*)\"");
     private static final Pattern BACKTICK_QUOTED_IDENTIFIER = Pattern.compile("`(\\w[\\w\\d\\.\\s]*)`");
+    private static final Character[]    ESCAPE_CHARS          = new Character[] {'@', '#', '&', '~', '/'};
+    private static final Set<Character> ESCAPE_CHARACTERS_SET = new HashSet<>(Arrays.asList(ESCAPE_CHARS));
 
     public static String get(String quotedIdentifier) {
         String ret;
@@ -116,10 +123,36 @@ public class IdentifierHelper {
         return s.replace("*", ".*").replace('?', '.');
     }
 
+    public static String escapeCharacters(String value) {
+        if (StringUtils.isEmpty(value)) {
+            return value;
+        }
+
+        StringBuilder sb = new StringBuilder();
+        for (int i = 0; i < value.length(); i++) {
+            char c = value.charAt(i);
+
+            if (c != '*' && ESCAPE_CHARACTERS_SET.contains(c)) {
+                sb.append('\\');
+            }
+            sb.append(c);
+        }
+
+        return sb.toString();
+    }
+
     public static String removeWildcards(String s) {
         return removeQuotes(s).replace("*", "").replace("?", "");
     }
 
+    public static boolean isCompleteValue(String s) {
+        return (StringUtils.isEmpty(s) || StringUtils.equals(s, "0") || StringUtils.equalsIgnoreCase(s, "false"));
+    }
+
+    public static boolean isInCompleteValue(String s) {
+        return StringUtils.isNotEmpty(s) && (StringUtils.equals(s, "1") || StringUtils.equalsIgnoreCase(s, "true"));
+    }
+
     public static class Info {
         private String   raw;
         private String   actual;
@@ -155,7 +188,7 @@ public class IdentifierHelper {
                     updateTypeInfo(lookup, context);
                     setIsTrait(context, lookup, attributeName);
                     updateEdgeInfo(lookup, context);
-                    introduceType = !isPrimitive() && !context.hasAlias(parts[0]);
+                    introduceType = (!isPrimitive() && !context.hasAlias(parts[0])) || isTrait;
                     updateSubTypes(lookup, context);
                 }
             } catch (NullPointerException ex) {
@@ -182,8 +215,11 @@ public class IdentifierHelper {
         private void updateEdgeInfo(org.apache.atlas.query.Lookup lookup, GremlinQueryComposer.Context context) {
             if (!isPrimitive && !isTrait && typeName != attributeName) {
                 edgeDirection = lookup.getRelationshipEdgeDirection(context, attributeName);
-                edgeLabel = lookup.getRelationshipEdgeLabel(context, attributeName);
-                typeName = lookup.getTypeFromEdge(context, attributeName);
+                edgeLabel     = lookup.getRelationshipEdgeLabel(context, attributeName);
+                typeName      = lookup.getTypeFromEdge(context, attributeName);
+            } else if (isTrait) {
+                edgeDirection = AtlasRelationshipEdgeDirection.OUT;
+                edgeLabel     = CLASSIFICATION_LABEL;
             }
         }
 
@@ -218,8 +254,11 @@ public class IdentifierHelper {
                     typeName = context.hasAlias(parts[0]) ?
                                        context.getTypeNameFromAlias(parts[0]) :
                                        parts[0];
-
-                    attributeName = parts[1];
+                    if (typeName != null && lookup.isTraitType(typeName) && !typeName.equals(context.getActiveTypeName())) {
+                        attributeName = typeName;
+                    } else {
+                        attributeName = parts[1];
+                    }
                 }
             }
 
