@@ -71,6 +71,10 @@ public class AtlasRelationshipDefStoreV2 extends AtlasAbstractDefStoreV2<AtlasRe
             throw new AtlasBaseException(AtlasErrorCode.TYPE_MATCH_FAILED, relationshipDef.getName(), TypeCategory.RELATIONSHIP.name());
         }
 
+        verifyTypeReadAccess(relationshipDef);
+
+        AtlasAuthorizationUtils.verifyAccess(new AtlasTypeAccessRequest(AtlasPrivilege.TYPE_CREATE, relationshipDef), "create relationship-def ", relationshipDef.getName());
+
         AtlasVertex relationshipDefVertex = typeDefStore.findTypeVertexByName(relationshipDef.getName());
 
         if (relationshipDefVertex != null) {
@@ -133,8 +137,6 @@ public class AtlasRelationshipDefStoreV2 extends AtlasAbstractDefStoreV2<AtlasRe
             LOG.debug("==> AtlasRelationshipDefStoreV1.create({}, {})", relationshipDef, preCreateResult);
         }
 
-        AtlasAuthorizationUtils.verifyAccess(new AtlasTypeAccessRequest(AtlasPrivilege.TYPE_CREATE, relationshipDef), "create relationship-def ", relationshipDef.getName());
-
         AtlasVertex vertex = (preCreateResult == null) ? preCreate(relationshipDef) : preCreateResult;
 
         AtlasRelationshipDef ret = toRelationshipDef(vertex);
@@ -216,6 +218,8 @@ public class AtlasRelationshipDefStoreV2 extends AtlasAbstractDefStoreV2<AtlasRe
             LOG.debug("==> AtlasRelationshipDefStoreV1.update({})", relationshipDef);
         }
 
+        verifyTypeReadAccess(relationshipDef);
+
         validateType(relationshipDef);
 
         AtlasRelationshipDef ret = StringUtils.isNotBlank(relationshipDef.getGuid())
@@ -535,4 +539,9 @@ public class AtlasRelationshipDefStoreV2 extends AtlasAbstractDefStoreV2<AtlasRe
                 Objects.equals(currentDef.getCardinality(), updatedDef.getCardinality());
     }
 
+    private void verifyTypeReadAccess(AtlasRelationshipDef relationshipDef) throws AtlasBaseException {
+        verifyTypeReadAccess(relationshipDef.getEndDef1().getType());
+        verifyTypeReadAccess(relationshipDef.getEndDef2().getType());
+    }
+
 }
