@@ -85,10 +85,5 @@ public abstract class AtlasGremlinQueryProvider {
         COMPARE_CONTAINS,
         COMPARE_IS_NULL,
         COMPARE_NOT_NULL,
-
-        TAG_PROPAGATION_IMPACTED_INSTANCES,
-        TAG_PROPAGATION_IMPACTED_INSTANCES_FOR_REMOVAL,
-        TAG_PROPAGATION_IMPACTED_INSTANCES_WITH_RESTRICTIONS,
-        TAG_PROPAGATION_IMPACTED_INSTANCES_EXCLUDE_RELATIONSHIP
     }
 }
