@@ -17,22 +17,33 @@
  */
 package org.apache.atlas.repository.impexp;
 
+import org.apache.atlas.TestUtilsV2;
+import org.apache.atlas.exception.AtlasBaseException;
+import org.apache.atlas.model.impexp.AtlasImportResult;
 import org.apache.atlas.model.typedef.AtlasBaseTypeDef;
 import org.apache.atlas.model.typedef.AtlasEntityDef;
 import org.apache.atlas.model.typedef.AtlasEnumDef;
 import org.apache.atlas.model.typedef.AtlasStructDef;
+import org.apache.atlas.model.typedef.AtlasTypesDef;
+import org.apache.atlas.repository.store.bootstrap.AtlasTypeDefStoreInitializer;
 import org.apache.atlas.store.AtlasTypeDefStore;
 import org.apache.atlas.type.AtlasTypeRegistry;
+import org.apache.atlas.utils.TestLoadModelUtils;
+import org.apache.atlas.utils.TestResourceFileUtils;
 import org.mockito.Mock;
-import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
 import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
+import java.io.IOException;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
 
+import static org.testng.Assert.assertEquals;
+import static org.testng.Assert.assertNotNull;
+
 public class TypeAttributeDifferenceTest {
     private TypeAttributeDifference typeAttributeDifference;
 
@@ -161,4 +172,15 @@ public class TypeAttributeDifferenceTest {
     private boolean invokeUpdate(AtlasEnumDef existing, AtlasEnumDef incoming) throws Exception {
         return typeAttributeDifference.addElements(existing, incoming);
     }
+
+    @Test
+    public void t1() throws IOException, AtlasBaseException {
+        AtlasTypesDef typesDef = TestResourceFileUtils.readObjectFromJson(".", "typesDef-bm", AtlasTypesDef.class);
+
+        AtlasImportResult result = new AtlasImportResult();
+        AtlasTypesDef typesToCreate = AtlasTypeDefStoreInitializer.getTypesToCreate(typesDef, this.typeRegistry);
+        typeDefStore.createTypesDef(typesToCreate);
+        typeAttributeDifference.updateTypes(typesDef, result);
+        assertNotNull(typesDef);
+    }
 }
