@@ -19,6 +19,7 @@
 package org.apache.atlas.web.filters;
 
 import org.apache.atlas.ApplicationProperties;
+import org.apache.atlas.AtlasConfiguration;
 import org.apache.atlas.security.SecurityProperties;
 import org.apache.atlas.utils.AuthenticationUtil;
 import org.apache.atlas.web.security.AtlasAuthenticationProvider;
@@ -28,6 +29,7 @@ import org.apache.commons.configuration.Configuration;
 import org.apache.commons.configuration.ConfigurationConverter;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.security.SecurityUtil;
+import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.security.authentication.client.AuthenticatedURL;
 import org.apache.hadoop.security.authentication.client.AuthenticationException;
 import org.apache.hadoop.security.authentication.client.KerberosAuthenticator;
@@ -38,8 +40,8 @@ import org.apache.hadoop.security.authentication.server.KerberosAuthenticationHa
 import org.apache.hadoop.security.authentication.util.Signer;
 import org.apache.hadoop.security.authentication.util.SignerException;
 import org.apache.hadoop.security.authentication.util.SignerSecretProvider;
+import org.apache.hadoop.security.authorize.AuthorizationException;
 import org.apache.hadoop.security.authorize.ProxyUsers;
-import org.apache.log4j.NDC;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.security.authentication.AbstractAuthenticationToken;
@@ -50,8 +52,9 @@ import org.springframework.security.core.context.SecurityContextHolder;
 import org.springframework.security.core.userdetails.User;
 import org.springframework.security.core.userdetails.UserDetails;
 import org.springframework.security.web.authentication.WebAuthenticationDetails;
+import org.springframework.security.web.authentication.logout.SecurityContextLogoutHandler;
 import org.springframework.stereotype.Component;
-import org.apache.hadoop.security.UserGroupInformation;
+
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;
 import javax.servlet.ServletContext;
@@ -69,10 +72,21 @@ import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.security.Principal;
 import java.text.SimpleDateFormat;
-import java.util.*;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Date;
+import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
+import java.util.TimeZone;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.hadoop.security.authorize.AuthorizationException;
+
+import static org.apache.atlas.web.filters.RestUtil.constructForwardableURL;
 
 
 /**
@@ -84,12 +98,14 @@ import org.apache.hadoop.security.authorize.AuthorizationException;
 public class AtlasAuthenticationFilter extends AuthenticationFilter {
     private static final Logger LOG = LoggerFactory.getLogger(AtlasAuthenticationFilter.class);
 
+    private   static final int            SESSION_TIMEOUT_DISABLED_VALUE = -1;
     private   static final String         CONFIG_KERBEROS_TOKEN_VALIDITY = "atlas.authentication.method.kerberos.token.validity";
     private   static final String         CONFIG_PROXY_USERS    = "atlas.proxyusers";
     private   static final String         PREFIX                = "atlas.authentication.method";
     private   static final String[]       DEFAULT_PROXY_USERS   = new String[] { "knox" };
     private   static final String         CONF_PROXYUSER_PREFIX = "atlas.proxyuser";
     protected static final ServletContext nullContext           = new NullServletContext();
+    private   static final String         ORIGINAL_URL_QUERY_PARAM = "originalUrl";
 
     private Signer               signer;
     private SignerSecretProvider secretProvider;
@@ -102,8 +118,9 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
     private Set<String>          atlasProxyUsers = new HashSet<>();
     private HttpServlet          optionsServlet;
     private boolean              supportTrustedProxy = false;
+    private int                  sessionTimeout;
 
-
+    private SecurityContextLogoutHandler logoutHandler;
 
     public AtlasAuthenticationFilter() {
         LOG.info("==> AtlasAuthenticationFilter()");
@@ -194,6 +211,10 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
         };
         optionsServlet.init();
 
+        if (sessionTimeout != -1) {
+            logoutHandler = new SecurityContextLogoutHandler();
+        }
+
         LOG.info("<== AtlasAuthenticationFilter.init(filterConfig={})", filterConfig);
 
     }
@@ -300,6 +321,10 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
 
 
         LOG.debug(" AuthenticationFilterConfig: {}", ret);
+        sessionTimeout = AtlasConfiguration.SESSION_TIMEOUT_SECS.getInt();
+        LOG.info("AtlasAuthenticationFilter: {} = {}: {}",
+                    AtlasConfiguration.SESSION_TIMEOUT_SECS.getPropertyName(), sessionTimeout, 
+                    (sessionTimeout == SESSION_TIMEOUT_DISABLED_VALUE) ? "Disabled" : "Enabled");
 
         supportKeyTabBrowserLogin = configuration.getBoolean("atlas.authentication.method.kerberos.support.keytab.browser.login", false);
         supportTrustedProxy = configuration.getBoolean("atlas.authentication.method.trustedproxy", true);
@@ -332,6 +357,8 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
             Authentication              existingAuth    = SecurityContextHolder.getContext().getAuthentication();
             HttpServletResponse         httpResponse    = (HttpServletResponse) response;
             AtlasResponseRequestWrapper responseWrapper = new AtlasResponseRequestWrapper(httpResponse);
+            String action = httpRequest.getParameter("action");
+            String doAsUser = request.getParameter("doAs");
 
             HeadersUtil.setHeaderMapAttributes(responseWrapper, HeadersUtil.X_FRAME_OPTIONS_KEY);
             HeadersUtil.setHeaderMapAttributes(responseWrapper, HeadersUtil.X_CONTENT_TYPE_OPTIONS_KEY);
@@ -344,6 +371,14 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
                 }
             }
 
+            if (logoutHandler != null && supportTrustedProxy && StringUtils.isNotEmpty(doAsUser) && StringUtils.equals(action, RestUtil.TIMEOUT_ACTION)) {
+                if (existingAuth != null) {
+                    logoutHandler.logout(httpRequest, httpResponse, existingAuth);
+                }
+                redirectTimeoutReqeust(httpRequest, httpResponse);
+                return;
+            }
+
             if (existingAuth == null) {
                 String authHeader = httpRequest.getHeader("Authorization");
 
@@ -365,6 +400,28 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
         }
     }
 
+    private void redirectTimeoutReqeust(HttpServletRequest httpRequest, HttpServletResponse httpResponse) throws IOException{
+        String logoutUrl = httpRequest.getRequestURL().toString();
+
+        logoutUrl =  StringUtils.replace(logoutUrl, httpRequest.getRequestURI(), RestUtil.LOGOUT_URL);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("logoutUrl value is " + logoutUrl);
+        }
+        String xForwardedURL = constructForwardableURL(httpRequest);
+
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("xForwardedURL = " + xForwardedURL);
+        }
+        String redirectUrl = RestUtil.constructRedirectURL(httpRequest, logoutUrl, xForwardedURL, ORIGINAL_URL_QUERY_PARAM);
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Redirect URL = " + redirectUrl);
+            LOG.debug("session id = " + httpRequest.getRequestedSessionId());
+        }
+
+        httpResponse.sendRedirect(redirectUrl);
+    }
 
 
     /**
@@ -717,6 +774,9 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
                 ((AbstractAuthenticationToken) finalAuthentication).setDetails(webDetails);
 
                 SecurityContextHolder.getContext().setAuthentication(finalAuthentication);
+                if (sessionTimeout != SESSION_TIMEOUT_DISABLED_VALUE) {
+                    httpRequest.getSession().setMaxInactiveInterval(sessionTimeout);
+                }
 
                 request.setAttribute("atlas.http.authentication.type", true);
 
@@ -731,17 +791,11 @@ public class AtlasAuthenticationFilter extends AuthenticationFilter {
             if (httpRequest.getMethod().equals("OPTIONS")) {
                 optionsServlet.service(request, response);
             } else {
-                try {
-                    String requestUser = httpRequest.getRemoteUser();
+                String requestUser = httpRequest.getRemoteUser();
 
-                    NDC.push(requestUser + ":" + httpRequest.getMethod() + httpRequest.getRequestURI());
+                LOG.info("Request from authenticated user: {}, URL={}", requestUser, Servlets.getRequestURI(httpRequest));
 
-                    LOG.info("Request from authenticated user: {}, URL={}", requestUser, Servlets.getRequestURI(httpRequest));
-
-                    filterChain.doFilter(servletRequest, servletResponse);
-                } finally {
-                    NDC.pop();
-                }
+                filterChain.doFilter(servletRequest, servletResponse);
             }
         }
     }
