@@ -21,6 +21,8 @@ import com.sun.jersey.core.header.FormDataContentDisposition;
 import com.sun.jersey.multipart.FormDataParam;
 import org.apache.atlas.AtlasErrorCode;
 import org.apache.atlas.EntityAuditEvent;
+import org.apache.atlas.RequestContext;
+import org.apache.atlas.annotation.Timed;
 import org.apache.atlas.authorize.AtlasAuthorizationUtils;
 import org.apache.atlas.authorize.AtlasEntityAccessRequest;
 import org.apache.atlas.authorize.AtlasPrivilege;
@@ -123,6 +125,7 @@ public class EntityREST {
      */
     @GET
     @Path("/guid/{guid}")
+    @Timed
     public AtlasEntityWithExtInfo getById(@PathParam("guid") String guid, @QueryParam("minExtInfo") @DefaultValue("false") boolean minExtInfo, @QueryParam("ignoreRelationships") @DefaultValue("false") boolean ignoreRelationships) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -147,6 +150,7 @@ public class EntityREST {
      */
     @GET
     @Path("/guid/{guid}/header")
+    @Timed
     public AtlasEntityHeader getHeaderById(@PathParam("guid") String guid) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -182,6 +186,7 @@ public class EntityREST {
      */
     @GET
     @Path("/uniqueAttribute/type/{typeName}/header")
+    @Timed
     public AtlasEntityHeader getEntityHeaderByUniqueAttributes(@PathParam("typeName") String typeName,
                                                                @Context HttpServletRequest servletRequest) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
@@ -225,6 +230,7 @@ public class EntityREST {
      */
     @GET
     @Path("/uniqueAttribute/type/{typeName}")
+    @Timed
     public AtlasEntityWithExtInfo getByUniqueAttributes(@PathParam("typeName") String typeName, @QueryParam("minExtInfo") @DefaultValue("false") boolean minExtInfo,
                                                         @QueryParam("ignoreRelationships") @DefaultValue("false") boolean ignoreRelationships, @Context HttpServletRequest servletRequest) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
@@ -267,6 +273,7 @@ public class EntityREST {
      *******/
     @PUT
     @Path("/uniqueAttribute/type/{typeName}")
+    @Timed
     public EntityMutationResponse partialUpdateEntityByUniqueAttrs(@PathParam("typeName") String typeName,
                                                                    @Context HttpServletRequest servletRequest,
                                                                    AtlasEntityWithExtInfo entityInfo) throws Exception {
@@ -310,6 +317,7 @@ public class EntityREST {
      */
     @DELETE
     @Path("/uniqueAttribute/type/{typeName}")
+    @Timed
     public EntityMutationResponse deleteByUniqueAttribute(@PathParam("typeName") String typeName,
                                                           @Context HttpServletRequest servletRequest) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
@@ -339,6 +347,7 @@ public class EntityREST {
      * @throws AtlasBaseException
      */
     @POST
+    @Timed
     public EntityMutationResponse createOrUpdate(AtlasEntityWithExtInfo entity) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -361,6 +370,7 @@ public class EntityREST {
      *******/
     @PUT
     @Path("/guid/{guid}")
+    @Timed
     public EntityMutationResponse partialUpdateEntityAttrByGuid(@PathParam("guid") String guid,
                                                                 @QueryParam("name") String attrName,
                                                                 Object attrValue) throws Exception {
@@ -387,6 +397,7 @@ public class EntityREST {
      */
     @DELETE
     @Path("/guid/{guid}")
+    @Timed
     public EntityMutationResponse deleteByGuid(@PathParam("guid") final String guid) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -410,6 +421,7 @@ public class EntityREST {
      */
     @GET
     @Path("/guid/{guid}/classification/{classificationName}")
+    @Timed
     public AtlasClassification getClassification(@PathParam("guid") String guid, @PathParam("classificationName") final String classificationName) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
         Servlets.validateQueryParamLength("classificationName", classificationName);
@@ -439,6 +451,7 @@ public class EntityREST {
      */
     @GET
     @Path("/guid/{guid}/classifications")
+    @Timed
     public AtlasClassification.AtlasClassifications getClassifications(@PathParam("guid") String guid) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -465,6 +478,7 @@ public class EntityREST {
      */
     @POST
     @Path("/uniqueAttribute/type/{typeName}/classifications")
+    @Timed
     public void addClassificationsByUniqueAttribute(@PathParam("typeName") String typeName, @Context HttpServletRequest servletRequest, List<AtlasClassification> classifications) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
 
@@ -495,6 +509,7 @@ public class EntityREST {
      */
     @POST
     @Path("/guid/{guid}/classifications")
+    @Timed
     public void addClassifications(@PathParam("guid") final String guid, List<AtlasClassification> classifications) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -521,6 +536,7 @@ public class EntityREST {
      */
     @PUT
     @Path("/uniqueAttribute/type/{typeName}/classifications")
+    @Timed
     public void updateClassificationsByUniqueAttribute(@PathParam("typeName") String typeName, @Context HttpServletRequest servletRequest, List<AtlasClassification> classifications) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
 
@@ -552,6 +568,7 @@ public class EntityREST {
      */
     @PUT
     @Path("/guid/{guid}/classifications")
+    @Timed
     public void updateClassifications(@PathParam("guid") final String guid, List<AtlasClassification> classifications) throws AtlasBaseException {
         Servlets.validateQueryParamLength("guid", guid);
 
@@ -580,6 +597,7 @@ public class EntityREST {
      */
     @DELETE
     @Path("/uniqueAttribute/type/{typeName}/classification/{classificationName}")
+    @Timed
     public void deleteClassificationByUniqueAttribute(@PathParam("typeName") String typeName, @Context HttpServletRequest servletRequest,@PathParam("classificationName") String classificationName) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
         Servlets.validateQueryParamLength("classificationName", classificationName);
@@ -612,6 +630,7 @@ public class EntityREST {
      */
     @DELETE
     @Path("/guid/{guid}/classification/{classificationName}")
+    @Timed
     public void deleteClassification(@PathParam("guid") String guid,
                                      @PathParam("classificationName") final String classificationName,
                                      @QueryParam("associatedEntityGuid") final String associatedEntityGuid) throws AtlasBaseException {
@@ -663,6 +682,7 @@ public class EntityREST {
      */
     @GET
     @Path("/bulk/uniqueAttribute/type/{typeName}")
+    @Timed
     public AtlasEntitiesWithExtInfo getEntitiesByUniqueAttributes(@PathParam("typeName") String typeName,
                                                                   @QueryParam("minExtInfo") @DefaultValue("false") boolean minExtInfo,
                                                                   @QueryParam("ignoreRelationships") @DefaultValue("false") boolean ignoreRelationships,
@@ -695,6 +715,7 @@ public class EntityREST {
      */
     @GET
     @Path("/bulk")
+    @Timed
     public AtlasEntitiesWithExtInfo getByGuids(@QueryParam("guid") List<String> guids, @QueryParam("minExtInfo") @DefaultValue("false") boolean minExtInfo, @QueryParam("ignoreRelationships") @DefaultValue("false") boolean ignoreRelationships) throws AtlasBaseException {
         if (CollectionUtils.isNotEmpty(guids)) {
             for (String guid : guids) {
@@ -725,6 +746,7 @@ public class EntityREST {
      */
     @POST
     @Path("/bulk")
+    @Timed
     public EntityMutationResponse createOrUpdate(AtlasEntitiesWithExtInfo entities) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -747,6 +769,7 @@ public class EntityREST {
      */
     @DELETE
     @Path("/bulk")
+    @Timed
     public EntityMutationResponse deleteByGuids(@QueryParam("guid") final List<String> guids) throws AtlasBaseException {
         if (CollectionUtils.isNotEmpty(guids)) {
             for (String guid : guids) {
@@ -768,10 +791,14 @@ public class EntityREST {
     }
 
     /**
-     * Bulk API to associate a tag to multiple entities
+     * Bulk API to associate a tag to multiple entities.
+     * Option 1: List of GUIDs to associate a tag
+     * Option 2: Typename and list of uniq attributes for entities to associate a tag
+     * Option 3: List of GUIDs and Typename with list of uniq attributes for entities to associate a tag
      */
     @POST
     @Path("/bulk/classification")
+    @Timed
     public void addClassification(ClassificationAssociateRequest request) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -780,15 +807,49 @@ public class EntityREST {
                 perf = AtlasPerfTracer.getPerfTracer(PERF_LOG, "EntityREST.addClassification(" + request  + ")");
             }
 
-            AtlasClassification classification = request == null ? null : request.getClassification();
-            List<String>        entityGuids    = request == null ? null : request.getEntityGuids();
+            AtlasClassification       classification           = request == null ? null : request.getClassification();
+            List<String>              entityGuids              = request == null ? null : request.getEntityGuids();
+            List<Map<String, Object>> entitiesUniqueAttributes = request == null ? null : request.getEntitiesUniqueAttributes();
+            String                    entityTypeName           = request == null ? null : request.getEntityTypeName();
 
             if (classification == null || StringUtils.isEmpty(classification.getTypeName())) {
                 throw new AtlasBaseException(AtlasErrorCode.INVALID_PARAMETERS, "no classification");
             }
 
-            if (CollectionUtils.isEmpty(entityGuids)) {
-                throw new AtlasBaseException(AtlasErrorCode.INVALID_PARAMETERS, "empty guid list");
+            if (hasNoGUIDAndTypeNameAttributes(request)) {
+                throw new AtlasBaseException(AtlasErrorCode.INVALID_PARAMETERS, "Need either list of GUIDs or entity type and list of qualified Names");
+            }
+
+            if (CollectionUtils.isNotEmpty(entitiesUniqueAttributes) && entityTypeName != null) {
+                AtlasEntityType entityType = ensureEntityType(entityTypeName);
+
+                if (CollectionUtils.isEmpty(entityGuids)) {
+                    entityGuids = new ArrayList<>();
+                }
+
+                for (Map<String, Object> eachEntityAttributes : entitiesUniqueAttributes) {
+                    try {
+                        String guid = entitiesStore.getGuidByUniqueAttributes(entityType, eachEntityAttributes);
+
+                        if (guid != null) {
+                            entityGuids.add(guid);
+                        }
+                    } catch (AtlasBaseException e) {
+                        if (RequestContext.get().isSkipFailedEntities()) {
+                            if (LOG.isDebugEnabled()) {
+                                LOG.debug("getByIds(): ignoring failure for entity with unique attributes {} and typeName {}: error code={}, message={}", eachEntityAttributes, entityTypeName, e.getAtlasErrorCode(), e.getMessage());
+                            }
+
+                            continue;
+                        }
+
+                        throw e;
+                    }
+                }
+
+                if (CollectionUtils.isEmpty(entityGuids)) {
+                    throw new AtlasBaseException(AtlasErrorCode.INVALID_PARAMETERS, "No guid found for given entity Type Name and list of attributes");
+                }
             }
 
             entitiesStore.addClassification(entityGuids, classification);
@@ -799,9 +860,13 @@ public class EntityREST {
 
     @GET
     @Path("{guid}/audit")
+    @Timed
     public List<EntityAuditEventV2> getAuditEvents(@PathParam("guid") String guid, @QueryParam("startKey") String startKey,
                                                    @QueryParam("auditAction") EntityAuditActionV2 auditAction,
-                                                   @QueryParam("count") @DefaultValue("100") short count) throws AtlasBaseException {
+                                                   @QueryParam("count") @DefaultValue("100") short count,
+                                                   @QueryParam("offset") @DefaultValue("-1") int offset,
+                                                   @QueryParam("sortBy") String sortBy,
+                                                   @QueryParam("sortOrder") String sortOrder) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
         try {
@@ -824,7 +889,9 @@ public class EntityREST {
 
             List<EntityAuditEventV2> ret = new ArrayList<>();
 
-            if(auditAction != null) {
+            if (sortBy != null || offset > -1) {
+                ret = auditRepository.listEventsV2(guid, auditAction, sortBy, StringUtils.equalsIgnoreCase(sortOrder, "desc"), offset, count);
+            } else if(auditAction != null) {
                 ret = auditRepository.listEventsV2(guid, auditAction, startKey, count);
             } else {
                 List events = auditRepository.listEvents(guid, startKey, count);
@@ -849,6 +916,7 @@ public class EntityREST {
     @GET
     @Path("bulk/headers")
     @Produces(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public AtlasEntityHeaders getEntityHeaders(@QueryParam("tagUpdateStartTime") long tagUpdateStartTime) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -874,6 +942,7 @@ public class EntityREST {
     @Path("bulk/setClassifications")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public String setClassifications(AtlasEntityHeaders entityHeaders) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -893,6 +962,7 @@ public class EntityREST {
     @Path("/guid/{guid}/businessmetadata")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void addOrUpdateBusinessAttributes(@PathParam("guid") final String guid, @QueryParam("isOverwrite") @DefaultValue("false") boolean isOverwrite, Map<String, Map<String, Object>> businessAttributes) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -911,6 +981,7 @@ public class EntityREST {
     @Path("/guid/{guid}/businessmetadata")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void removeBusinessAttributes(@PathParam("guid") final String guid, Map<String, Map<String, Object>> businessAttributes) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -929,6 +1000,7 @@ public class EntityREST {
     @Path("/guid/{guid}/businessmetadata/{bmName}")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void addOrUpdateBusinessAttributes(@PathParam("guid") final String guid, @PathParam("bmName") final String bmName, Map<String, Object> businessAttributes) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -947,6 +1019,7 @@ public class EntityREST {
     @Path("/guid/{guid}/businessmetadata/{bmName}")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void removeBusinessAttributes(@PathParam("guid") final String guid, @PathParam("bmName") final String bmName, Map<String, Object> businessAttributes) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -971,6 +1044,7 @@ public class EntityREST {
     @Path("/guid/{guid}/labels")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void setLabels(@PathParam("guid") final String guid, Set<String> labels) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -994,6 +1068,7 @@ public class EntityREST {
     @Path("/guid/{guid}/labels")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void removeLabels(@PathParam("guid") final String guid, Set<String> labels) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -1017,6 +1092,7 @@ public class EntityREST {
     @Path("/guid/{guid}/labels")
     @Produces(Servlets.JSON_MEDIA_TYPE)
     @Consumes(Servlets.JSON_MEDIA_TYPE)
+    @Timed
     public void addLabels(@PathParam("guid") final String guid, Set<String> labels) throws AtlasBaseException {
         AtlasPerfTracer perf = null;
 
@@ -1033,6 +1109,7 @@ public class EntityREST {
 
     @POST
     @Path("/uniqueAttribute/type/{typeName}/labels")
+    @Timed
     public void setLabels(@PathParam("typeName") String typeName, Set<String> labels,
                           @Context HttpServletRequest servletRequest) throws AtlasBaseException {
 
@@ -1060,6 +1137,7 @@ public class EntityREST {
 
     @PUT
     @Path("/uniqueAttribute/type/{typeName}/labels")
+    @Timed
     public void addLabels(@PathParam("typeName") String typeName, Set<String> labels,
                           @Context HttpServletRequest servletRequest) throws AtlasBaseException {
         Servlets.validateQueryParamLength("typeName", typeName);
@@ -1086,6 +1164,7 @@ public class EntityREST {
 
     @DELETE
     @Path("/uniqueAttribute/type/{typeName}/labels")
+    @Timed
     public void removeLabels(@PathParam("typeName") String typeName, Set<String> labels,
                              @Context HttpServletRequest servletRequest) throws AtlasBaseException {
 
@@ -1240,6 +1319,7 @@ public class EntityREST {
     @POST
     @Path("/businessmetadata/import")
     @Consumes(MediaType.MULTIPART_FORM_DATA)
+    @Timed
     public BulkImportResponse importBMAttributes(@FormDataParam("file") InputStream uploadedInputStream,
                                                  @FormDataParam("file") FormDataContentDisposition fileDetail) throws AtlasBaseException {
 
@@ -1256,4 +1336,9 @@ public class EntityREST {
 
         return ret;
     }
+
+    private boolean hasNoGUIDAndTypeNameAttributes(ClassificationAssociateRequest request) {
+        return (request == null || (CollectionUtils.isEmpty(request.getEntityGuids()) &&
+                (CollectionUtils.isEmpty(request.getEntitiesUniqueAttributes()) || request.getEntityTypeName() == null)));
+    }
 }
